
      addSimpleType(poTypes, "ADM_GRENSE", "administrativGrense", OFTString);

      addSimpleType(poTypes, "ADRESSE", "adresse", OFTString);

      addSimpleType(poTypes, "ADRESSEREFKODE", "adresseReferansekode", OFTString);

      addSimpleType(poTypes, "AJOURFØRTAV", "ajourførtAv", OFTString);

      addSimpleType(poTypes, "AJOURFØRTDATO", "ajourførtDato", OFTDate);

      addSimpleType(poTypes, "AKGEOLTEMA", "annetKvTema", OFTInteger);

      addSimpleType(poTypes, "AKVA_ART", "akvaArt", OFTInteger);

      addSimpleType(poTypes, "AKVA_ENHET", "akvaEnhet", OFTInteger);

      addSimpleType(poTypes, "AKVA_KONSTR", "akvaKonstruksjon", OFTInteger);

      addSimpleType(poTypes, "AKVA_NR", "akvaKonsesjonsnummer", OFTInteger);

      addSimpleType(poTypes, "AKVA_STATUS", "akvaKonsesjonsstatus", OFTString);

      addSimpleType(poTypes, "AKVA_TYPE", "akvaKonsesjonstype", OFTString);

      addSimpleType(poTypes, "AKVAKONSESJONSFORMÅL", "akvaKonsesjonsformål", OFTString);

      addSimpleType(poTypes, "AKVATEMP", "akvaTemperatur", OFTInteger);

      addSimpleType(poTypes, "AKVSYMBOL", "andreKvSymbol", OFTInteger);

      addSimpleType(poTypes, "ALDERBESKRIVELSE", "alderBeskrivelse", OFTString);

      addSimpleType(poTypes, "ALGE_KONS", "algeKonsentrasjon", OFTInteger);

      addSimpleType(poTypes, "ALGE_TYP", "algeType", OFTString);

      addSimpleType(poTypes, "ALM-TYP", "allmenningtype", OFTString);

      addSimpleType(poTypes, "ALT_AREALBYGNING", "alternativtArealBygning", OFTReal);

      addSimpleType(poTypes, "ALTERN_FNR", "altForekomstNr", OFTString);

      addSimpleType(poTypes, "ALTERNATIVTNAVN", "alternativtNavn", OFTString);

      addSimpleType(poTypes, "ANBELINTYP", "annenBergartLinjetype", OFTInteger);

      addSimpleType(poTypes, "ANDREKILDERBELASTNING", "andrekilderBelastning", OFTInteger);

      addSimpleType(poTypes, "ANKRINGSBRUK", "ankringsbruk", OFTInteger);

      addSimpleType(poTypes, "ANKRTYP", "ankringstype", OFTInteger);

      addSimpleType(poTypes, "ANLEGGNØDSTRØM", "anleggNødstrøm", OFTString);

      addSimpleType(poTypes, "ANLEGGSNUMMER", "anleggsnummer", OFTString);

      addSimpleType(poTypes, "ANNEN_VANNB_ELEK", "annenVannbehandlingAvhElektrisitet", OFTString);

      addSimpleType(poTypes, "ANNENLUFTHAVN", "annenLufthavn", OFTInteger);

      addSimpleType(poTypes, "ANNENMATRENHET", "annenMatrEnhet", OFTString);

      addSimpleType(poTypes, "ANT_ANALYS", "antallAnalyser", OFTInteger);

      addSimpleType(poTypes, "ANT_ANS", "antallAnsatte", OFTInteger);

      addSimpleType(poTypes, "ANT_ÅRSV", "antallÅrsverk", OFTInteger);

      addSimpleType(poTypes, "ANTALL_BAD", "antallBad", OFTInteger);

      addSimpleType(poTypes, "ANTALL_BOENHETER", "antallBoenheter", OFTInteger);

      addSimpleType(poTypes, "ANTALL_ETASJER", "antall etasjer", OFTInteger);

      addSimpleType(poTypes, "ANTALL_ROM", "antallRom", OFTInteger);

      addSimpleType(poTypes, "ANTALL_RØKLØP", "antallRøkløp", OFTReal);

      addSimpleType(poTypes, "ANTALL_WC", "antallWC", OFTInteger);

      addSimpleType(poTypes, "ANTALLFASTBOENDE", "antallFastboende", OFTInteger);

      addSimpleType(poTypes, "ANTALLFRITIDSBOLIGER", "antallFritidsboliger", OFTInteger);

      addSimpleType(poTypes, "ANTALLIDENTISKELYS", "antallIdentiskeLys", OFTInteger);

      addSimpleType(poTypes, "ANTALLSKISPOR", "antallSkispor", OFTInteger);

      addSimpleType(poTypes, "ANTALLSKORSTEINER", "antallSkorsteiner", OFTInteger);

      addSimpleType(poTypes, "ANTDRIFT", "landbruksregAntBedrifter", OFTInteger);

      addSimpleType(poTypes, "ARAVGRTYPE", "arealressursAvgrensingType", OFTInteger);

      addSimpleType(poTypes, "ARDYRKING", "arealressursDyrkbarjord", OFTInteger);

      addSimpleType(poTypes, "AREAL", "areal", OFTReal);

      addSimpleType(poTypes, "AREALBRUK_RESTR", "arealbrukRestriksjon", OFTInteger);

      addSimpleType(poTypes, "AREALENHET", "arealenhet", OFTString);

      addSimpleType(poTypes, "AREALINNSJØ", "arealInnsjø", OFTReal);

      addSimpleType(poTypes, "AREALKILDE", "arealkilde", OFTInteger);

      addSimpleType(poTypes, "AREALMERKNAD", "arealmerknad", OFTString);

      addSimpleType(poTypes, "AREALNEDBØRFELT", "arealNedbørfelt", OFTString);

      addSimpleType(poTypes, "AREALREGINE", "arealRegine", OFTReal);

      addSimpleType(poTypes, "AREALST", "arealbruksstatus", OFTInteger);

      addSimpleType(poTypes, "AREALVERDI_IND", "arealverdiindikator", OFTString);

      addSimpleType(poTypes, "ARENKEL", "arealressursGruppertEnkel", OFTInteger);

      addSimpleType(poTypes, "ARGRUNNF", "arealressursGrunnforhold", OFTInteger);

      addSimpleType(poTypes, "ARKARTSTD", "arealressursKartstandard", OFTString);

      addSimpleType(poTypes, "ARNFJBRUK", "arealressursNaturgrunnlagForJordbruk", OFTInteger);

      addSimpleType(poTypes, "ARSKOGBON", "arealressursSkogbonitet", OFTInteger);

      addSimpleType(poTypes, "ART_ENGELSK", "engelskArtsnavn", OFTString);

      addSimpleType(poTypes, "ART_LATIN", "vitenskapeligArtsnavn", OFTString);

      addSimpleType(poTypes, "ART_NORSK", "norskArtsnavn", OFTString);

      addSimpleType(poTypes, "ART_TAKSONOMI", "taksonomiskKode", OFTInteger);

      addSimpleType(poTypes, "ARTRESLAG", "arealressursTreslag", OFTInteger);

      addSimpleType(poTypes, "ARTYPE", "arealressursArealtype", OFTInteger);

      addSimpleType(poTypes, "ARUTETYPE", "annenRutetype", OFTString);

      addSimpleType(poTypes, "ARVANLIG", "arealressursGruppertVanlig", OFTInteger);

      addSimpleType(poTypes, "ARVEGET", "arealressursVegetasjonsdekke", OFTInteger);

      addSimpleType(poTypes, "ASKOG", "potensiellSkogbonitet", OFTInteger);

      addSimpleType(poTypes, "ATIL", "arealtilstand", OFTInteger);

      addSimpleType(poTypes, "AVFALLSDEP", "avfallDeponiEgnethet", OFTInteger);

      addSimpleType(poTypes, "AVFALLTYPE", "avfallType", OFTInteger);

      addSimpleType(poTypes, "AVGIFTSBELAGT", "avgiftsbelagt", OFTString);

      addSimpleType(poTypes, "AVGJDATO", "avgjørelsesdato", OFTDate);

      addSimpleType(poTypes, "AVGRENSNINGSTYPE", "avgrensningstype", OFTInteger);

      addSimpleType(poTypes, "AVKJ", "avkjørselsbestemmelse", OFTInteger);

      addSimpleType(poTypes, "AVKLARTEIERE", "avklartEiere", OFTString);

      addSimpleType(poTypes, "AVLØP", "avløp", OFTInteger);

      addSimpleType(poTypes, "AVLØP_TILKNYTNING", "tilknyttetKommunaltAvløp", OFTString);

      addSimpleType(poTypes, "AVLØPINNSJØ", "avløpInnsjø", OFTReal);

      addSimpleType(poTypes, "AVLØPRENSEPRINSIPP", "avløpRenseprinsipp", OFTString);

      addSimpleType(poTypes, "AVLØPSANLEGGEIERFORM", "avløpsanleggEierform", OFTInteger);

      addSimpleType(poTypes, "AVLØPSANLEGGTYPE", "avløpsanleggtype", OFTInteger);

      addSimpleType(poTypes, "AVSETNING", "avsetningstype", OFTInteger);

      addSimpleType(poTypes, "AVSETNRATE", "avsetnRate", OFTString);

      addSimpleType(poTypes, "BAKKEOPPLØSNING", "bakkeoppløsning", OFTReal);

      addSimpleType(poTypes, "BARMARKSLØYPETYPE", "barmarksløypeType", OFTString);

      addSimpleType(poTypes, "BEALDERBST", "bergartAlderBestemmelse", OFTString);

      addSimpleType(poTypes, "BEBYGD_AREAL", "bebygdAreal", OFTReal);

      addSimpleType(poTypes, "BEFARGEKO", "cmykFargekode", OFTString);

      addSimpleType(poTypes, "BEHSTAT", "behandlingsstatus", OFTInteger);

      addSimpleType(poTypes, "BEITEBRUKERID", "reinbeitebrukerID", OFTString);

      addSimpleType(poTypes, "BEITETID", "beitetid", OFTString);

      addSimpleType(poTypes, "BEITETIDVEDTAK", "beitetidVedtak", OFTString);

      addSimpleType(poTypes, "BEKJSAMSET", "bergartKjemiskSammensetning", OFTString);

      addSimpleType(poTypes, "BEKORNSTR", "bergartKornstørrelse", OFTString);

      addSimpleType(poTypes, "BELIGG", "omgivelsetypeTraséseksjon", OFTInteger);

      addSimpleType(poTypes, "BELIGGENHET", "beliggenhet", OFTString);

      addSimpleType(poTypes, "BELYSNING", "belysning", OFTString);

      addSimpleType(poTypes, "BEREGNET", "beregningsDato", OFTDate);

      addSimpleType(poTypes, "BEREGNETÅR", "beregnetÅr", OFTString);

      addSimpleType(poTypes, "BERGFARGE", "bergartFarge", OFTString);

      addSimpleType(poTypes, "BERGGRENSETYPE", "berggrunnGrensetype", OFTInteger);

      addSimpleType(poTypes, "BESK_ELEMENT", "beskrivelseElement", OFTString);

      addSimpleType(poTypes, "BESKRIV", "tiltaksbeskrivelse", OFTString);

      addSimpleType(poTypes, "BESKRIVELSE", "beskrivelse", OFTString);

      addSimpleType(poTypes, "BESTEMMELSEOMRNAVN", "bestemmelseOmrådeNavn", OFTString);

      addSimpleType(poTypes, "BESTRUKTUR", "bergartStruktur", OFTString);

      addSimpleType(poTypes, "BESYMBOLTY", "bergartSymbol", OFTInteger);

      addSimpleType(poTypes, "BETEKSTUR", "bergartTekstur", OFTString);

      addSimpleType(poTypes, "BETJENINGSGRAD", "betjeningsgrad", OFTString);

      addSimpleType(poTypes, "BILDE-BIT-PIXEL", "bitsPerPixel", OFTInteger);

      addSimpleType(poTypes, "BILDE-FIL", "bildeFil", OFTString);

      addSimpleType(poTypes, "PLANPÅSKRIFTTYPE", "planpåskriftype", OFTInteger);

      addSimpleType(poTypes, "BILDEKATEGORI", "bildekategori", OFTInteger);

      addSimpleType(poTypes, "BILDEMÅLESTOKK", "bildemålestokk", OFTInteger);

      addSimpleType(poTypes, "BILDENUMMER", "bildenummer", OFTInteger);

      addSimpleType(poTypes, "BILDE-SYS", "bildeSystem", OFTInteger);

      addSimpleType(poTypes, "BILDE-TYPE", "bildeType", OFTString);

      addSimpleType(poTypes, "BILDE-UNDERTYPE", "bildeUndertype", OFTString);

      addSimpleType(poTypes, "BISPENUMMER", "bispenummer", OFTInteger);

      addSimpleType(poTypes, "BKLASSIFIK", "berggrunnKlassifikasjon", OFTInteger);

      addSimpleType(poTypes, "BLOKK", "steinOgBlokk", OFTString);

      addSimpleType(poTypes, "BLOKKAREAL", "blokkareal", OFTReal);

      addSimpleType(poTypes, "BMANDEL", "bmAndel", OFTInteger);

      addSimpleType(poTypes, "BMANTALL", "bmAntall", OFTInteger);

      addSimpleType(poTypes, "BMARSTID", "bmÅrstid", OFTInteger);

      addSimpleType(poTypes, "BMART", "bmArt", OFTString);

      addSimpleType(poTypes, "BMENHET", "bmEnhet", OFTInteger);

      addSimpleType(poTypes, "BMFUNK", "bmOmrådefunksjon", OFTInteger);

      addSimpleType(poTypes, "BMFUNKVAL", "bmFunksjonskvalitet", OFTInteger);

      addSimpleType(poTypes, "BMKILDTYP", "bmKildetype", OFTInteger);

      addSimpleType(poTypes, "BMKILDVURD", "bmKildevurdering", OFTInteger);

      addSimpleType(poTypes, "BMNATYP", "bmNaturtype", OFTString);

      addSimpleType(poTypes, "BMNATYPMARIN", "bmNaturtypeMarin", OFTString);

      addSimpleType(poTypes, "BMNATYPMARINUTF", "bmNaturtypeMarinUtforming", OFTString);

      addSimpleType(poTypes, "BMNATYPUTF", "bmNaturtypeUtforming", OFTString);

      addSimpleType(poTypes, "BMREGDATO", "bmRegistreringsdato", OFTDate);

      addSimpleType(poTypes, "BMTRUETKAT", "bmTruethetskategori", OFTString);

      addSimpleType(poTypes, "BMVERDI", "bmVerdi", OFTString);

      addSimpleType(poTypes, "BMVILTVEKT", "bmViltvekt", OFTInteger);

      addSimpleType(poTypes, "BNR", "bruksnummer", OFTInteger);

      addSimpleType(poTypes, "BOKST", "bokstav", OFTString);

      addSimpleType(poTypes, "BOLTTYPE", "boltType", OFTInteger);

      addSimpleType(poTypes, "BOREDAGER", "antallBoredager", OFTInteger);

      addSimpleType(poTypes, "BOREDATO", "boredato", OFTDate);

      addSimpleType(poTypes, "BOREDYP", "boredyp", OFTReal);

      addSimpleType(poTypes, "BOREFIRMA", "borefirma", OFTString);

      addSimpleType(poTypes, "BOREINNRETN", "boreinnretningsnavn", OFTString);

      addSimpleType(poTypes, "BORESLUTT", "boreslutt", OFTDate);

      addSimpleType(poTypes, "BORESTART", "borestart", OFTDate);

      addSimpleType(poTypes, "BORETYPE", "boringType", OFTInteger);

      addSimpleType(poTypes, "BORHELNING", "gfborehHelning", OFTInteger);

      addSimpleType(poTypes, "BORHULLNR", "borhullNummer", OFTString);

      addSimpleType(poTypes, "BORLENGDE", "gfborehLengde", OFTReal);

      addSimpleType(poTypes, "BORRETNING", "gfborehRetning", OFTInteger);

      addSimpleType(poTypes, "BOT_OK_INT", "botaniskØkologiskInteresse", OFTString);

      addSimpleType(poTypes, "BRANSJE", "bransje", OFTString);

      addSimpleType(poTypes, "BREDDE", "trasébredde", OFTInteger);

      addSimpleType(poTypes, "BRENNVIDDE", "brennvidde", OFTReal);

      addSimpleType(poTypes, "BRENSELTANKNEDGR", "brenseltankNedgravd", OFTInteger);

      addSimpleType(poTypes, "BRETYPE", "bretype", OFTInteger);

      addSimpleType(poTypes, "BRUDDLENGDE", "bruddlengde", OFTReal);

      addSimpleType(poTypes, "BRUEIER", "brueier", OFTString);

      addSimpleType(poTypes, "BRUK_GRAD", "kulturlandskapBrukGrad", OFTString);

      addSimpleType(poTypes, "BRUKONSTRTYPE", "brukonstruksjonstype", OFTString);

      addSimpleType(poTypes, "BRUKSAREAL", "bruksareal", OFTReal);

      addSimpleType(poTypes, "BRUKSAREALANNET", "bruksarealTilAnnet", OFTReal);

      addSimpleType(poTypes, "BRUKSAREALBOLIG", "bruksarealTilBolig", OFTReal);

      addSimpleType(poTypes, "BRUKSAREALTOTALT", "bruksarealTotalt", OFTReal);

      addSimpleType(poTypes, "BRUKSENHETSTYPE", "bruksenhetstype", OFTString);

      addSimpleType(poTypes, "BRUKSFREKVENS", "friluftsområdeBruksfrekvens", OFTInteger);

      addSimpleType(poTypes, "BRUKSNAVN", "bruksnavn", OFTString);

      addSimpleType(poTypes, "BRUMATERIAL", "brumaterial", OFTString);

      addSimpleType(poTypes, "BRUOVERBRU", "bruOverBru", OFTString);

      addSimpleType(poTypes, "BRUTRAFIKKTYPE", "brutrafikktype", OFTString);

      addSimpleType(poTypes, "BRUÅPNING", "bruåpningsmåte", OFTString);

      addSimpleType(poTypes, "BRØNN_REGNR", "brønnRegNr", OFTInteger);

      addSimpleType(poTypes, "BRØNN_RESULTAT", "brønnresultat", OFTString);

      addSimpleType(poTypes, "BRØNNKLASSE", "petroleumsbrønnklasse", OFTString);

      addSimpleType(poTypes, "BRØNNTYPE", "petroleumsbrønntype", OFTString);

      addSimpleType(poTypes, "BRØYTEAREALTILGANG", "brøytearealtilgang", OFTInteger);

      addSimpleType(poTypes, "BRØYTEAREALTYPE", "brøytearealtype", OFTInteger);

      addSimpleType(poTypes, "BRØYTEBREDDE", "brøytebredde", OFTInteger);

      addSimpleType(poTypes, "BRØYTEPRIORITET", "brøyteprioritet", OFTString);

      addSimpleType(poTypes, "BRØYTERESTRIKSJON", "brøyterestriksjon", OFTString);

      addSimpleType(poTypes, "BRØYTESIDE", "brøyteside", OFTString);

      addSimpleType(poTypes, "BRØYTETYPE", "brøytetype", OFTString);

      addSimpleType(poTypes, "BUNNTYP", "bunntype", OFTString);

      addSimpleType(poTypes, "BUNNTYPE", "bunntype", OFTInteger);

      addSimpleType(poTypes, "BYDELSNAVN", "bydelsnavn", OFTString);

      addSimpleType(poTypes, "BYDELSNUMMER", "bydelsnummer", OFTInteger);

      addSimpleType(poTypes, "BYGGHØYDEIMETER", "bygghøydeIMeter", OFTInteger);

      addSimpleType(poTypes, "BYGGNR", "bygningsnummer", OFTInteger);

      addSimpleType(poTypes, "BYGGSTAT", "bygningsstatus", OFTString);

      addSimpleType(poTypes, "BYGGTYP_NBR", "bygningstype", OFTInteger);

      addSimpleType(poTypes, "BYGGVERK", "byggverkbestemmelse", OFTInteger);

      addSimpleType(poTypes, "BYGN_ENDR_KODE", "bygningsendringskode", OFTString);

      addSimpleType(poTypes, "BYGN_ENDR_LØPENR", "endringsløpenummer", OFTInteger);

      addSimpleType(poTypes, "BYGN_HIST_DATO", "bygningshistorikkDato", OFTDate);

      addSimpleType(poTypes, "BYGN_REF_TYPE", "bygningReferansetype", OFTString);

      addSimpleType(poTypes, "BYGN_SAKSNR", "bygnSaksnr", OFTString);

      addSimpleType(poTypes, "BYGNINGSFUNKSJON", "bygningsfunksjon", OFTInteger);

      addSimpleType(poTypes, "BÆREEVNEBENEVNELSE", "bæreevnebenevnelse", OFTString);

      addSimpleType(poTypes, "BØYE_FORM", "bøyeform", OFTInteger);

      addSimpleType(poTypes, "BÅNDLAGTFREMTIL", "båndlagtFremTil", OFTDate);

      addSimpleType(poTypes, "CLEIER", "CL_Eier", OFTString);

      addSimpleType(poTypes, "D", "dybde", OFTInteger);

      addSimpleType(poTypes, "DA_ANNET", "landbruksregArealAnnet", OFTInteger);

      addSimpleType(poTypes, "DA_JORD_D", "landbruksregArealJordIDrift", OFTReal);

      addSimpleType(poTypes, "DA_JORD_E", "landbruksregArealJordbruk", OFTInteger);

      addSimpleType(poTypes, "DA_SKOG", "landbruksregArealSkog", OFTInteger);

      addSimpleType(poTypes, "DAMFORMÅL", "damFormål", OFTString);

      addSimpleType(poTypes, "DAMFUNKSJON", "damFunksjon", OFTInteger);

      addSimpleType(poTypes, "DAMLENGDE", "damLengde", OFTReal);

      addSimpleType(poTypes, "DAMTYPE", "damType", OFTString);

      addSimpleType(poTypes, "DATAFANGSTDATO", "datafangstdato", OFTDateTime);

      addSimpleType(poTypes, "DATAUTTAKSDATO", "datauttaksdato", OFTDateTime);

      addSimpleType(poTypes, "DATERMETOD", "dateringMetode", OFTInteger);

      addSimpleType(poTypes, "DATUM", "datum", OFTString);

      addSimpleType(poTypes, "DEFORMASJONFASE", "deformasjonFase", OFTInteger);

      addSimpleType(poTypes, "DEKKENAVN", "dekkeEnhetNavn", OFTString);

      addSimpleType(poTypes, "DEKKETYPE", "dekketype", OFTString);

      addSimpleType(poTypes, "DEKNINGSNUMMER", "dekningsnummer", OFTString);

      addSimpleType(poTypes, "DEL_BRED", "posisjonBredde", OFTInteger);

      addSimpleType(poTypes, "DEL_DYBD", "posisjonDybde", OFTInteger);

      addSimpleType(poTypes, "DELOMRÅDENAVN", "delområdenavn", OFTString);

      addSimpleType(poTypes, "DELOMRÅDENUMMER", "delområdenummer", OFTString);

      addSimpleType(poTypes, "DELSTREKNINGSNUMMER", "delstrekningsnummer", OFTString);

      addSimpleType(poTypes, "DEPONISTATUS", "deponistatus", OFTInteger);

      addSimpleType(poTypes, "DEPONITYPE", "deponitype", OFTInteger);

      addSimpleType(poTypes, "DESINFANLAVHELEK", "desinfAnleggAvhElektrisitet", OFTString);

      addSimpleType(poTypes, "DIGITALISERINGSMÅLESTOKK", "digitaliseringsmålestokk", OFTInteger);

      addSimpleType(poTypes, "DIM-BREDDE", "tekstTegnBredde", OFTReal);

      addSimpleType(poTypes, "DIM-HØYDE", "tekstTegnHøyde", OFTReal);

      addSimpleType(poTypes, "DISTKODE", "reinbeitedistriktID", OFTString);

      addSimpleType(poTypes, "DK_MANDEL", "dyrkningspotensialMandel", OFTInteger);

      addSimpleType(poTypes, "DK_MANDEL_A", "nedklassifiseringMandel", OFTInteger);

      addSimpleType(poTypes, "DK_NEDBOR", "nedbørsbasert", OFTInteger);

      addSimpleType(poTypes, "DK_NEDBOR_A", "nedklassifiseringNedbør", OFTInteger);

      addSimpleType(poTypes, "DK_VANN", "vanningsbasert", OFTInteger);

      addSimpleType(poTypes, "DK_VANN_A", "nedklassifiseringVanning", OFTInteger);

      addSimpleType(poTypes, "DOKUMENTASJONSTYPE", "dokumentasjonType", OFTInteger);

      addSimpleType(poTypes, "D-REF-INT", "vertikalReferanseInternasjonalDybde", OFTInteger);

      addSimpleType(poTypes, "DRIFTFHOLD", "driftForhold", OFTInteger);

      addSimpleType(poTypes, "DRIFTMETOD", "driftMetode", OFTInteger);

      addSimpleType(poTypes, "DRSENTER", "jordregisterDriftssenter", OFTInteger);

      addSimpleType(poTypes, "DYBDE", "dybde", OFTReal);

      addSimpleType(poTypes, "DYBDE_MAX", "maximumsdybde", OFTReal);

      addSimpleType(poTypes, "DYBDE_MIN", "minimumsdybde", OFTReal);

      addSimpleType(poTypes, "DYBDEFJELL", "dybdeTilFjell", OFTReal);

      addSimpleType(poTypes, "DYBDEKVIKKLEIRE", "dybdeTilKvikkleire", OFTReal);

      addSimpleType(poTypes, "DYBDEMÅLEMETODE", "dybemålemetode", OFTInteger);

      addSimpleType(poTypes, "DYBDE-REF", "dybdeReferanse", OFTString);

      addSimpleType(poTypes, "DYBDETYPE", "dybdetype", OFTInteger);

      addSimpleType(poTypes, "DYPMIDDEL", "dypMiddel", OFTInteger);

      addSimpleType(poTypes, "DYPSTØRSTMÅLT", "dypStørstMålt", OFTInteger);

      addSimpleType(poTypes, "SERIENUMMER", "serienummer", OFTString);

      addSimpleType(poTypes, "DYRKING", "jordregisterDyrkingsjord", OFTString);

      addSimpleType(poTypes, "EIER", "geodataeier", OFTString);

      addSimpleType(poTypes, "EIERFORHOLD", "eierforhold", OFTString);

      addSimpleType(poTypes, "EIERFORM", "eierformType", OFTInteger);

      addSimpleType(poTypes, "EKOORD-H", "jordregisterKoordinatHøyde", OFTInteger);

      addSimpleType(poTypes, "EKOORD-N", "jordregisterKoordinatNord", OFTInteger);

      addSimpleType(poTypes, "EKOORD-Ø", "jordregisterKoordinatØst", OFTInteger);

      addSimpleType(poTypes, "ENDRET_TID", "tidspunktEndring", OFTDateTime);

      addSimpleType(poTypes, "ENDRET_TYPE", "typeEndring", OFTString);

      addSimpleType(poTypes, "ENDRINGSGRAD", "endringsgrad", OFTString);

      addSimpleType(poTypes, "ENERGIKILDE", "energikilde", OFTString);

      addSimpleType(poTypes, "ENHET", "enhet", OFTReal);

      addSimpleType(poTypes, "ENHET-D", "enhetDybde", OFTReal);

      addSimpleType(poTypes, "ENHET-H", "enhetHøyde", OFTReal);

      addSimpleType(poTypes, "EROSJONGS", "erosjonsrisikoGrasdekke", OFTInteger);

      addSimpleType(poTypes, "EROSJONHP", "erosjonsrisikoHøstpløying", OFTInteger);

      addSimpleType(poTypes, "ETABLERINGSDATO", "etableringsdato", OFTDate);

      addSimpleType(poTypes, "ETABLERT", "fastmerkeEtableringsdato", OFTDate);

      addSimpleType(poTypes, "ETASJENUMMER", "etasjenummer", OFTInteger);

      addSimpleType(poTypes, "ETASJEPLAN", "etasjeplan", OFTString);

      addSimpleType(poTypes, "ETASJETALL", "etasjetall", OFTString);

      addSimpleType(poTypes, "ETAT", "etat", OFTString);

      addSimpleType(poTypes, "F_TYPE", "fiskeType", OFTInteger);

      addSimpleType(poTypes, "FAGOMRÅD", "ledningsfagområde", OFTInteger);

      addSimpleType(poTypes, "FALLHØYDE", "fallHøyde", OFTReal);

      addSimpleType(poTypes, "FAO_KODE", "faoKode", OFTString);

      addSimpleType(poTypes, "FARTØY_ID", "fartøyIdentifikasjon", OFTString);

      addSimpleType(poTypes, "FASADE", "fasade", OFTInteger);

      addSimpleType(poTypes, "FBNAVN", "fiskebedriftsnavn", OFTString);

      addSimpleType(poTypes, "FBNR", "fiskebruksnummer", OFTInteger);

      addSimpleType(poTypes, "FBNR_FYLK", "fiskebruksnummerFylke", OFTString);

      addSimpleType(poTypes, "FELTNAVN", "feltbetegnelse", OFTString);

      addSimpleType(poTypes, "FELTREGISTRERTAV", "feltegistrertAv", OFTString);

      addSimpleType(poTypes, "FIGF_ID", "figurFørSkifteIdent", OFTInteger);

      addSimpleType(poTypes, "FILM", "film", OFTString);

      addSimpleType(poTypes, "FIRMA", "firmanavn", OFTString);

      addSimpleType(poTypes, "FISK_KODE", "artskode", OFTInteger);

      addSimpleType(poTypes, "FISKE_BEDR_ANDEL", "fiskebedriftsandel", OFTInteger);

      addSimpleType(poTypes, "FISKE_BEDR_EIER", "fiskebedriftseier", OFTString);

      addSimpleType(poTypes, "FISKE_BEDR_OMR", "fiskebedriftsområde", OFTInteger);

      addSimpleType(poTypes, "FISKE_BEDR_PROD", "fiskebedriftsprodukt", OFTInteger);

      addSimpleType(poTypes, "FISKE_BEDR_SERVICE", "fiskebedriftservice", OFTInteger);

      addSimpleType(poTypes, "FISKE_KAP_ENH", "fiskekapasitetEnhet", OFTInteger);

      addSimpleType(poTypes, "FISKE_KAPASITET", "fiskekapasitet", OFTInteger);

      addSimpleType(poTypes, "FISKE_TYPE", "fisketype", OFTInteger);

      addSimpleType(poTypes, "FISKERI_BRUK_TYPE", "fiskeribrukstype", OFTInteger);

      addSimpleType(poTypes, "FISKERI_RESS_TYPE", "fiskeriressursOmrådetype", OFTInteger);

      addSimpleType(poTypes, "FISKERIREDSKAP_GEN_AKTIV", "fiskeriredskapGenAktiv", OFTInteger);

      addSimpleType(poTypes, "FISKERIREDSKAP_GEN_PASSIV", "fiskeriredskapGenPassiv", OFTInteger);

      addSimpleType(poTypes, "FISKERIREDSKAP_SPES_AKTIV", "fiskeriredskapSpesAktiv", OFTInteger);

      addSimpleType(poTypes, "FISKERIREDSKAP_SPES_PASSIV", "fiskeriredskapSpesPassiv", OFTInteger);

      addSimpleType(poTypes, "FJELL", "fjellblotninger", OFTInteger);

      addSimpleType(poTypes, "FJORDID", "fjordidentifikasjon", OFTString);

      addSimpleType(poTypes, "FLODBOLGEHOYDE", "flodbolgehoyde", OFTInteger);

      addSimpleType(poTypes, "FLOMLAVPUNKT", "flomLavPunkt", OFTReal);

      addSimpleType(poTypes, "FLYFIRMA", "flyfirma", OFTString);

      addSimpleType(poTypes, "FLYHØYDE", "flyhøyde", OFTInteger);

      addSimpleType(poTypes, "FLYRESTR", "flyRestriksjon", OFTInteger);

      addSimpleType(poTypes, "FMADKOMST", "fastmerkeAdkomst", OFTString);

      addSimpleType(poTypes, "FMDIM", "fastmerkeDiameter", OFTInteger);

      addSimpleType(poTypes, "FMHREF", "fastmerkeHøyderef", OFTString);

      addSimpleType(poTypes, "FMIDDATO", "fastmerkeIdDato", OFTDate);

      addSimpleType(poTypes, "FMIDGML", "fastmerkeIdGammel", OFTString);

      addSimpleType(poTypes, "FMINST", "fastmerkeInstitusjon", OFTString);

      addSimpleType(poTypes, "FMKOMM", "fastmerkeKommune", OFTInteger);

      addSimpleType(poTypes, "FMMERK", "fastmerkeMerknader", OFTString);

      addSimpleType(poTypes, "FMNAVN", "fastmerkeNavn", OFTString);

      addSimpleType(poTypes, "FMNUMMER", "fastmerkeNummer", OFTString);

      addSimpleType(poTypes, "FMREFBER", "fastmerkeRefGrunnrisBeregning", OFTString);

      addSimpleType(poTypes, "FMREFHBER", "fastmerkeRefHøydeBeregning", OFTString);

      addSimpleType(poTypes, "FMRESTR", "fastmerkeRestriksjon", OFTString);

      addSimpleType(poTypes, "FMSREF", "fastmerkeSentrumRef", OFTString);

      addSimpleType(poTypes, "FNR", "festenummer", OFTInteger);

      addSimpleType(poTypes, "FONTENE_TYPE", "fontenetype", OFTInteger);

      addSimpleType(poTypes, "FOREKNAVN", "navnRastoffobj", OFTString);

      addSimpleType(poTypes, "FOREKOM_ID", "identRastoffobj", OFTInteger);

      addSimpleType(poTypes, "FORHOLDANDREHUS", "forholdAndreHus", OFTString);

      addSimpleType(poTypes, "FORHÅNDSTALL", "forhåndstall", OFTInteger);

      addSimpleType(poTypes, "FORLENGET_DATO", "forlengetDato", OFTDate);

      addSimpleType(poTypes, "FORMASJON", "formasjonTotalDyp", OFTString);

      addSimpleType(poTypes, "FORMELFLATE", "kvFormFlatetype", OFTInteger);

      addSimpleType(poTypes, "FORMELLIN", "kvFormLinjetype", OFTInteger);

      addSimpleType(poTypes, "FORMELPKT", "kvFormPunkttype", OFTInteger);

      addSimpleType(poTypes, "FORMÅLSEKSJON", "formålSeksjonKode", OFTString);

      addSimpleType(poTypes, "FORUR_AREAL", "forurensetAreal", OFTInteger);

      addSimpleType(poTypes, "FORUR_GRUNNTYPE", "forurensetGrunnType", OFTInteger);

      addSimpleType(poTypes, "FORUR_HOVEDGRUPPE", "forurensningHovedgruppe", OFTInteger);

      addSimpleType(poTypes, "FORV_MYND", "forvaltningMyndighet", OFTString);

      addSimpleType(poTypes, "FORV_PLAN", "forvaltningPlan", OFTInteger);

      addSimpleType(poTypes, "FOSSILTYPE", "fossilNavn", OFTString);

      addSimpleType(poTypes, "FOTODATO", "fotodato", OFTDate);

      addSimpleType(poTypes, "FOTOGRAF", "fotograf", OFTString);

      addSimpleType(poTypes, "FOTRUTETYPE", "fotrutetype", OFTInteger);

      addSimpleType(poTypes, "FRASPORNODEKILOMETER", "fraSpornodeKilometer", OFTReal);

      addSimpleType(poTypes, "FRASPORNODETEKST", "fraSpornodeTekst", OFTString);

      addSimpleType(poTypes, "FRASPORNODETYPE", "fraSpornodeType", OFTString);

      addSimpleType(poTypes, "F-REF-INT", "friseilingReferanseInternasjonal", OFTInteger);

      addSimpleType(poTypes, "FREG", "jordregisterFreg", OFTInteger);

      addSimpleType(poTypes, "FRIDRIFTSTILSYN", "friluftslivsområdeDriftstilsyn", OFTInteger);

      addSimpleType(poTypes, "FRIEGNETHET", "friluftslivsområdeEgnethet", OFTInteger);

      addSimpleType(poTypes, "FRIPLANST", "friluftslivsområdePlanStatus", OFTInteger);

      addSimpleType(poTypes, "FRISEILHØYDE", "friseilingshøyde", OFTReal);

      addSimpleType(poTypes, "FRISEIL-REF", "frilseilingReferanse", OFTString);

      addSimpleType(poTypes, "FRISIKRING", "friluftslivSikring", OFTInteger);

      addSimpleType(poTypes, "FRISPERR", "frisperring", OFTInteger);

      addSimpleType(poTypes, "FRISTMATRIKKELFØRINGSKRAV", "fristMatrikkelføringskrav", OFTDate);

      addSimpleType(poTypes, "FRISTOPPMÅLING", "fristOppmåling", OFTDate);

      addSimpleType(poTypes, "FRITILRETTELEGGING", "friluftslivsområdeTilrettelegging", OFTInteger);

      addSimpleType(poTypes, "FRITYPE", "friluftslivsområdeType", OFTString);

      addSimpleType(poTypes, "FRIVERDI", "friluftslivsområdeVerdi", OFTString);

      addSimpleType(poTypes, "F-STRENG", "formatertStreng", OFTString);

      addSimpleType(poTypes, "FUNDAMENTERING", "fundamentering", OFTInteger);

      addSimpleType(poTypes, "FYDELTEMA", "fylkesdeltema", OFTInteger);

      addSimpleType(poTypes, "FYLKESNR", "fylkesnummer", OFTInteger);

      addSimpleType(poTypes, "FYRLISTEKARAKTER", "fyrlisteKarakter", OFTString);

      addSimpleType(poTypes, "FYRLISTENUMMER", "fyrlistenummer", OFTString);

      addSimpleType(poTypes, "FYSENHET", "fysiskEnhet", OFTInteger);

      addSimpleType(poTypes, "FYSISKMILJØ", "fysiskMiljø", OFTInteger);

      addSimpleType(poTypes, "FYSPARAM", "fysiskParameter", OFTInteger);

      addSimpleType(poTypes, "FYSSTR", "fysiskStorrelse", OFTReal);

      addSimpleType(poTypes, "FØLGER_TERRENGDET", "følgerTerrengdetalj", OFTString);

      addSimpleType(poTypes, "FØRSTEDATAFANGSTDATO", "førsteDatafangstdato", OFTDateTime);

      addSimpleType(poTypes, "FØRSTEDIGITALISERINGSDATO", "førsteDigitaliseringsdato", OFTDateTime);

      addSimpleType(poTypes, "GARDIDNR", "landbruksregProdusentId", OFTInteger);

      addSimpleType(poTypes, "GATENAVN", "gatenavn", OFTString);

      addSimpleType(poTypes, "GATENR", "gatenummer", OFTInteger);

      addSimpleType(poTypes, "GENRESTR", "generellrestriksjon", OFTInteger);

      addSimpleType(poTypes, "GEOALDER", "geolAlder", OFTInteger);

      addSimpleType(poTypes, "GEOALDER_FRA", "geolMaksAlder", OFTInteger);

      addSimpleType(poTypes, "GEOALDER_TIL", "geolMinAlder", OFTInteger);

      addSimpleType(poTypes, "GEOBESK", "geolBeskrivelse", OFTString);

      addSimpleType(poTypes, "GEO-DATUM", "geoDatumInternasjonal", OFTInteger);

      addSimpleType(poTypes, "GEOFELTNR", "geologFeltnummer", OFTString);

      addSimpleType(poTypes, "GEOFORMASJ", "geolFormasjonNavn", OFTString);

      addSimpleType(poTypes, "GEOGRUPPE", "geolGruppeNavn", OFTString);

      addSimpleType(poTypes, "GEOHOVERDI", "geolHorisontalverdi", OFTInteger);

      addSimpleType(poTypes, "GEOKARTNR", "geolKartnummer", OFTInteger);

      addSimpleType(poTypes, "GEOKOORD", "geoKoordinatverdiEnhet", OFTInteger);

      addSimpleType(poTypes, "GEOLOKNR", "geolLokalitetnummer", OFTReal);

      addSimpleType(poTypes, "GEO-PROJ", "geoProjeksjon", OFTInteger);

      addSimpleType(poTypes, "GEOPÅVISNINGTYPE", "geolPavisningtype", OFTInteger);

      addSimpleType(poTypes, "GEOSITENO", "geositeNummer", OFTInteger);

      addSimpleType(poTypes, "GEO-SONE", "geoSoneProjeksjon", OFTInteger);

      addSimpleType(poTypes, "GEOVERDIVURD", "geolVerdivurdering", OFTInteger);

      addSimpleType(poTypes, "GEOVEVERDI", "geolVertikalverdi", OFTInteger);

      addSimpleType(poTypes, "GFANOMALI", "geofAnomali", OFTInteger);

      addSimpleType(poTypes, "GFDYPSTR", "geofDyp", OFTReal);

      addSimpleType(poTypes, "GFDYPTYPE", "geofDyptype", OFTInteger);

      addSimpleType(poTypes, "GFFALLBREGMET", "geofFallBeregnMetode", OFTInteger);

      addSimpleType(poTypes, "GFFALLSTR", "geofFallstorrelse", OFTInteger);

      addSimpleType(poTypes, "GFFLATE", "geofFlate", OFTInteger);

      addSimpleType(poTypes, "GFL_INFO", "geofLinjeInfo", OFTInteger);

      addSimpleType(poTypes, "GFLINJE", "geofTolkLinjetype", OFTInteger);

      addSimpleType(poTypes, "GFMETODE", "geofMetode", OFTInteger);

      addSimpleType(poTypes, "GFP_INFO", "geofPunktInfo", OFTInteger);

      addSimpleType(poTypes, "GFSTROK", "geofStrokretning", OFTInteger);

      addSimpleType(poTypes, "GFTOLK", "geofTolkMetode", OFTInteger);

      addSimpleType(poTypes, "GFUTLLEN", "geofLengdeUtlegg", OFTInteger);

      addSimpleType(poTypes, "GFUTLRETN", "geofRetningUtlegg", OFTInteger);

      addSimpleType(poTypes, "GFUTLTYPE", "geofTypeUtlegg", OFTInteger);

      addSimpleType(poTypes, "GJENNOMFØRINGSFRIST", "gjennomføringsfrist", OFTDate);

      addSimpleType(poTypes, "GJENTAKSINTERVAL", "gjentaksInterval", OFTInteger);

      addSimpleType(poTypes, "GJERDETYPE", "sikringGjerdetype", OFTInteger);

      addSimpleType(poTypes, "GKEKSTRAKT", "geokEkstrakt", OFTInteger);

      addSimpleType(poTypes, "GKENHET", "geokEnhet", OFTInteger);

      addSimpleType(poTypes, "GKFRADYP", "geokFraDyp", OFTInteger);

      addSimpleType(poTypes, "GKFRAKSJON", "geokFraksjon", OFTInteger);

      addSimpleType(poTypes, "GKHORISONT", "geokHorisont", OFTInteger);

      addSimpleType(poTypes, "GKHOVMEDIUM", "geokHovedmedium", OFTInteger);

      addSimpleType(poTypes, "GKMEDIUM", "geokMedium", OFTInteger);

      addSimpleType(poTypes, "GKRETSNAVN", "grunnkretsnavn", OFTString);

      addSimpleType(poTypes, "GKTILDYP", "geokTilDyp", OFTInteger);

      addSimpleType(poTypes, "GKVARIABEL", "geokVariabel", OFTString);

      addSimpleType(poTypes, "GNR", "gårdsnummer", OFTInteger);

      addSimpleType(poTypes, "GR_TYPE", "grensetypeSjø", OFTInteger);

      addSimpleType(poTypes, "GRAVERT", "gravertTekst", OFTString);

      addSimpleType(poTypes, "GRDANNELSE", "grotteDannelse", OFTInteger);

      addSimpleType(poTypes, "GRDIMSJOND", "grotteDimDiameter", OFTInteger);

      addSimpleType(poTypes, "GRDIMSJONH", "grotteDimHoyre", OFTInteger);

      addSimpleType(poTypes, "GRDIMSJONO", "grotteDimOver", OFTInteger);

      addSimpleType(poTypes, "GRDIMSJONU", "grotteDimUnder", OFTInteger);

      addSimpleType(poTypes, "GRDIMSJONV", "grotteDimVenstre", OFTInteger);

      addSimpleType(poTypes, "GRENSEMERKENEDSATTI", "grensemerkeNedsasttI", OFTString);

      addSimpleType(poTypes, "GRENSEPUNKTNUMMER", "grensepunktnummer", OFTString);

      addSimpleType(poTypes, "GRENSEPUNKTTYPE", "grensepunkttype", OFTInteger);

      addSimpleType(poTypes, "GRENSEVEDTAK", "grenseVedtak", OFTString);

      addSimpleType(poTypes, "GRFORMELM", "grotteFormElement", OFTInteger);

      addSimpleType(poTypes, "GRGANGFORM", "grotteGaForm", OFTInteger);

      addSimpleType(poTypes, "GRGANGTYPE", "grotteGaType", OFTString);

      addSimpleType(poTypes, "GRHOYDE", "grotteHoyde", OFTInteger);

      addSimpleType(poTypes, "GRLINTYPE", "grotteLinjetype", OFTInteger);

      addSimpleType(poTypes, "GROTLEGEME", "grotteLegeme", OFTString);

      addSimpleType(poTypes, "GROTNOYAKT", "grotteNoyaktighet", OFTString);

      addSimpleType(poTypes, "GROTTELAST", "grotteLast", OFTInteger);

      addSimpleType(poTypes, "GROTTENAVN", "grotteNavn", OFTString);

      addSimpleType(poTypes, "GROTTEPLAN", "grottePlan", OFTString);

      addSimpleType(poTypes, "GROTTLENKE", "grotteLenke", OFTInteger);

      addSimpleType(poTypes, "GRPKTTYPE", "grottePktType", OFTInteger);

      addSimpleType(poTypes, "GRPUNKTNR", "grottePktNummer", OFTString);

      addSimpleType(poTypes, "GRUNNBORINGREF", "grunnBoringReferanse", OFTString);

      addSimpleType(poTypes, "GRUNNFHOLD", "losmGrunnforhold", OFTInteger);

      addSimpleType(poTypes, "GRUNNGASS", "grunnGass", OFTInteger);

      addSimpleType(poTypes, "GRUNNKRETS", "grunnkretsnummer", OFTInteger);

      addSimpleType(poTypes, "GRUNNLINJENAVN", "grunnlinjepunktnavn", OFTString);

      addSimpleType(poTypes, "GRUNNLINJENUMMER", "grunnlinjepunktnummer", OFTString);

      addSimpleType(poTypes, "GRUNNRISSREFERANSESPOR", "grunnrissreferanseSpor", OFTString);

      addSimpleType(poTypes, "GRUNNVANN", "grunnvannPotensiale", OFTInteger);

      addSimpleType(poTypes, "GRUNNVERDI", "grunnVerdi", OFTReal);

      addSimpleType(poTypes, "GRVARSEL", "grotteVarsel", OFTInteger);

      addSimpleType(poTypes, "GVAKT_PROS", "geoVernAktivProsess", OFTString);

      addSimpleType(poTypes, "GVAREAL", "geoVernAreal", OFTString);

      addSimpleType(poTypes, "GVDLIKEHOLD", "geoVernVedlikehold", OFTString);

      addSimpleType(poTypes, "GVERNE_ID", "geoVernObjektId", OFTInteger);

      addSimpleType(poTypes, "GVERNETYPE", "geoVernTematype", OFTInteger);

      addSimpleType(poTypes, "GVERNHTYPE", "geoVernHovedtype", OFTString);

      addSimpleType(poTypes, "GVERNKRT_A", "geoVernAKriterie", OFTString);

      addSimpleType(poTypes, "GVERNKRT_B", "geoVernBKriterie", OFTString);

      addSimpleType(poTypes, "GVERNKRT_C", "geoVernCKriterie", OFTString);

      addSimpleType(poTypes, "GVERNVERDI", "geoVernVerdi", OFTInteger);

      addSimpleType(poTypes, "GVGRENSETY", "geoVernGrensetype", OFTInteger);

      addSimpleType(poTypes, "GVHINNHLD", "geoVernHovInnhold", OFTString);

      addSimpleType(poTypes, "GVINNGREP", "geoVernInngrep", OFTString);

      addSimpleType(poTypes, "GVLITTRTUR", "geoVernLitteratur", OFTString);

      addSimpleType(poTypes, "GVOFFNTLGJ", "geoVernOffentliggjoring", OFTString);

      addSimpleType(poTypes, "GVOMR_NAVN", "geoVernOmrNavn", OFTString);

      addSimpleType(poTypes, "GVPROALDER", "geoVernProsessalder", OFTInteger);

      addSimpleType(poTypes, "GVSAKSTATUS", "geoVernSakStatus", OFTInteger);

      addSimpleType(poTypes, "GVSTATUS", "geoVernType", OFTInteger);

      addSimpleType(poTypes, "GVSYSTEM", "geoVernSystem", OFTString);

      addSimpleType(poTypes, "GVTINNHLD", "geoVernTilleggInnhold", OFTString);

      addSimpleType(poTypes, "GVVKT_PROS", "geoVernViktigProsess", OFTString);

      addSimpleType(poTypes, "GYLDIGFRA", "gyldigFra", OFTDate);

      addSimpleType(poTypes, "GYLDIGTIL", "gyldigTil", OFTDate);

      addSimpleType(poTypes, "H", "høyde", OFTInteger);

      addSimpleType(poTypes, "H_EUREF89", "høydeOverEuref89", OFTReal);

      addSimpleType(poTypes, "H_KAT_LANDSK", "hovedkategoriLandskap", OFTString);

      addSimpleType(poTypes, "HAR_HEIS", "harHeis", OFTString);

      addSimpleType(poTypes, "HASTIGHETSENHET", "hastighetsenhet", OFTString);

      addSimpleType(poTypes, "HAVNE_D_ADM", "havnedistriktadministrasjon", OFTInteger);

      addSimpleType(poTypes, "HAVNE_ID", "havneidentifikasjon", OFTInteger);

      addSimpleType(poTypes, "HAVNEAVSNITTNUMMER", "havneavsnittnummer", OFTInteger);

      addSimpleType(poTypes, "HAVNEAVSNITTSTATUS", "havneavsnittstatus", OFTString);

      addSimpleType(poTypes, "HAVNEAVSNITTTYPE", "havneavsnitttype", OFTString);

      addSimpleType(poTypes, "HAVNETERMINALISPSNUMMER", "havneterminalISPSnummer", OFTInteger);

      addSimpleType(poTypes, "HAVNETERMINALNUMMER", "havneterminalnummer", OFTInteger);

      addSimpleType(poTypes, "HAVNETERMINALSTATUS", "havneterminalstatus", OFTString);

      addSimpleType(poTypes, "HAVNETERMINALTYPE", "havneterminaltype", OFTString);

      addSimpleType(poTypes, "HBERGKODE", "hovedBergKode", OFTInteger);

      addSimpleType(poTypes, "HELLING", "helling", OFTInteger);

      addSimpleType(poTypes, "HENDELSE", "trasénodeHendelsestype", OFTInteger);

      addSimpleType(poTypes, "HENSYNSONENAVN", "hensynSonenavn", OFTString);

      addSimpleType(poTypes, "HFLOM", "vannstandRegHøyestRegistrerte", OFTReal);

      addSimpleType(poTypes, "HINDERFLATE_TYPE", "hinderFlateType", OFTInteger);

      addSimpleType(poTypes, "HINDERFLATEPENETRERINGSTYPE", "hinderflatepenetreringstype", OFTInteger);

      addSimpleType(poTypes, "HJELPELINJETYPE", "hjelpelinjetype", OFTString);

      addSimpleType(poTypes, "HJEMMELSGRUNNLAG", "hjemmelsgrunnlag", OFTString);

      addSimpleType(poTypes, "HJULTRYKK", "hjultrykk", OFTString);

      addSimpleType(poTypes, "H-MÅLEMETODE", "målemetodeHøyde", OFTInteger);

      addSimpleType(poTypes, "H-NØYAKTIGHET", "nøyaktighetHøyde", OFTInteger);

      addSimpleType(poTypes, "HOB", "høydeOverBakken", OFTReal);

      addSimpleType(poTypes, "HOLDNINGSKLASSE", "holdningsklasse", OFTInteger);

      addSimpleType(poTypes, "HOR_BÆREKONSTR", "horisontalBærekonstr", OFTInteger);

      addSimpleType(poTypes, "HOVEDPARSELL", "hovedParsell", OFTInteger);

      addSimpleType(poTypes, "HOVEDTEIG", "hovedteig", OFTString);

      addSimpleType(poTypes, "HREF", "høydereferanse", OFTString);

      addSimpleType(poTypes, "H-REF-INT", "høydeReferanseInternasjonal", OFTInteger);

      addSimpleType(poTypes, "HRV", "vannstandHøyesteRegulert", OFTReal);

      addSimpleType(poTypes, "HUSHOLDBELASTNING", "husholdBelastning", OFTInteger);

      addSimpleType(poTypes, "HUSLØPENR", "husLøpenr", OFTInteger);

      addSimpleType(poTypes, "HUSNR", "husNr", OFTInteger);

      addSimpleType(poTypes, "HVANN", "vannstandHøyestRegistrert", OFTReal);

      addSimpleType(poTypes, "HYTTE_ID", "hytteId", OFTInteger);

      addSimpleType(poTypes, "HYTTEEIER", "hytteeier", OFTInteger);

      addSimpleType(poTypes, "HØYDE", "høyde", OFTReal);

      addSimpleType(poTypes, "HØYDE_TIL_NAV", "høydeTilNavet", OFTInteger);

      addSimpleType(poTypes, "HØYDE-REF", "høyde-Referanse", OFTString);

      addSimpleType(poTypes, "HØYDEREFERANSESPOR", "høydereferanseSpor", OFTString);

      addSimpleType(poTypes, "HØYDE-TYPE", "høydeType", OFTString);

      addSimpleType(poTypes, "ID", "identifikasjon", OFTString);

      addSimpleType(poTypes, "IKRAFT", "ikrafttredelsesdato", OFTDate);

      addSimpleType(poTypes, "IMOTOPPMERKETYPE", "imoToppmerketype", OFTInteger);

      addSimpleType(poTypes, "IMP", "impedimentprosentSkog", OFTInteger);

      addSimpleType(poTypes, "INDEKSMIN", "indeksMineral", OFTString);

      addSimpleType(poTypes, "INDIKATOR", "indikatorFastmerkenummer", OFTString);

      addSimpleType(poTypes, "INDUSTRIBELASTNING", "industriBelastning", OFTInteger);

      addSimpleType(poTypes, "INFILT", "infiltrasjonEvne", OFTInteger);

      addSimpleType(poTypes, "INFORMASJON", "informasjon", OFTString);

      addSimpleType(poTypes, "FAGOMRÅDEGRUPPE", "fagområdegruppe", OFTString);

      addSimpleType(poTypes, "FAGOMRÅDE_FULLT_NAVN", "fagområdets fulle navn", OFTString);

      addSimpleType(poTypes, "INON_AVS", "inngrepsfriSoneAvstand", OFTReal);

      addSimpleType(poTypes, "INONSONE", "inngrepsfrieNaturområderINorgeSone", OFTString);

      addSimpleType(poTypes, "INRT_FUNKSJON", "innretningsfunksjon", OFTString);

      addSimpleType(poTypes, "INRT_HOVEDTYPE", "innretningshovedtype", OFTString);

      addSimpleType(poTypes, "INRT_MATR", "innretningsmaterialtype", OFTString);

      addSimpleType(poTypes, "INRT_NAVN", "innretningsnavn", OFTString);

      addSimpleType(poTypes, "INRT_TYPE", "innretningstype", OFTString);

      addSimpleType(poTypes, "INST_EFFEKT", "installertEffekt", OFTInteger);

      addSimpleType(poTypes, "INSTALLASJONSBØYEKATEGORI", "installasjonsbøyekategori", OFTInteger);

      addSimpleType(poTypes, "INSTALLERT_ÅR", "installertÅr", OFTDate);

      addSimpleType(poTypes, "INT_STAT", "internasjonalStatus", OFTInteger);

      addSimpleType(poTypes, "J_LREG", "jordregisterLreg", OFTString);

      addSimpleType(poTypes, "JERNBANEEIER", "jernbaneeier", OFTString);

      addSimpleType(poTypes, "JERNBANETYPE", "jernbanetype", OFTString);

      addSimpleType(poTypes, "JORD", "jordklassifikasjon", OFTInteger);

      addSimpleType(poTypes, "JORDARB", "anbefaltJordarbeiding", OFTInteger);

      addSimpleType(poTypes, "JORDART", "losmassetype", OFTInteger);

      addSimpleType(poTypes, "JREGAREAL", "jordregisterAreal", OFTReal);

      addSimpleType(poTypes, "JREGEKODE", "jordregisterStatusEiendom", OFTInteger);

      addSimpleType(poTypes, "JRFIGNR", "jordregisterFigurnummer", OFTInteger);

      addSimpleType(poTypes, "JSR_AREAL", "jordskifteArealtilstand", OFTInteger);

      addSimpleType(poTypes, "JSVSAK", "jordskifterettenSaksnummer", OFTString);

      addSimpleType(poTypes, "JXAREAL", "annetareal", OFTInteger);

      addSimpleType(poTypes, "KABELTYPE", "kabeltype", OFTInteger);

      addSimpleType(poTypes, "KAI_DYBDE", "kaiDybde", OFTReal);

      addSimpleType(poTypes, "KAI_TYPE", "kaiTypeInformasjon", OFTInteger);

      addSimpleType(poTypes, "KALIBRERINGSRAPPORT", "kalibreringsrapport", OFTString);

      addSimpleType(poTypes, "KAMERATYPE", "kameratype", OFTString);

      addSimpleType(poTypes, "KAPASITETLANGEKJØRETØY", "kapasitetLangekjøretøy", OFTInteger);

      addSimpleType(poTypes, "KAPASITETPERSONBILER", "kapasitetPersonbiler", OFTInteger);

      addSimpleType(poTypes, "KAPASITETPERSONEKVIVALENTER", "kapasitetPersonekvivalenter", OFTInteger);

      addSimpleType(poTypes, "KARDINALMERKETYPE", "kardinalmerketype", OFTInteger);

      addSimpleType(poTypes, "KARTID", "kartbladindeks", OFTString);

      addSimpleType(poTypes, "KARTLEGGINGSETAPPE", "kartleggingsetappe", OFTString);

      addSimpleType(poTypes, "KARTREG", "kartregistrering", OFTInteger);

      addSimpleType(poTypes, "KARTSIGNATUR", "kartsignatur", OFTString);

      addSimpleType(poTypes, "KARTTYPE", "karttype", OFTString);

      addSimpleType(poTypes, "KBISPENR", "bispedømmenummer", OFTInteger);

      addSimpleType(poTypes, "KILDEPRIVATVANNF", "kildePrivatVannforsyning", OFTInteger);

      addSimpleType(poTypes, "KJELLER", "kjeller", OFTInteger);

      addSimpleType(poTypes, "KJERNEOMRÅDESTATUS", "kjerneområdestatus", OFTString);

      addSimpleType(poTypes, "KJØKKENTILGANG", "kjøkkentilgang", OFTInteger);

      addSimpleType(poTypes, "KLASSIFISERING", "kulturlandskapKlassifisering", OFTString);

      addSimpleType(poTypes, "KLOR_FØR_FORBRUK", "klorKontakttidFørForbruk", OFTInteger);

      addSimpleType(poTypes, "KLORO_MAKS", "klorofyllMaksimum", OFTInteger);

      addSimpleType(poTypes, "KLOTPAR", "klotoideParameter", OFTReal);

      addSimpleType(poTypes, "KLOTRAD1", "klotoideRadius 1", OFTReal);

      addSimpleType(poTypes, "KLOTRAD2", "klotoideRadius 2", OFTReal);

      addSimpleType(poTypes, "RUTEVANSKELIGHETSGRAD", "rutevanskelighetsgrad", OFTString);

      addSimpleType(poTypes, "RWY_BÆREEVNE_BEN", "bæreevnebenevnelse", OFTString);

      addSimpleType(poTypes, "RWY_TYPE", "rullebaneType", OFTString);

      addSimpleType(poTypes, "RWYMERK", "rullebaneoppmerking", OFTInteger);

      addSimpleType(poTypes, "RYDDEBREDDE", "ryddebredde", OFTInteger);

      addSimpleType(poTypes, "RØR_ENDE_PKT", "ledningsendepunkt", OFTString);

      addSimpleType(poTypes, "RØR_START_PKT", "ledningsstartpunkt", OFTString);

      addSimpleType(poTypes, "RØRLEDNINGSTYPE", "rørledningstype", OFTInteger);

      addSimpleType(poTypes, "SAK_AVSLUTT", "sakAvsluttet", OFTString);

      addSimpleType(poTypes, "SAKSNR", "saksnummer", OFTInteger);

      addSimpleType(poTypes, "SAKSOMF", "saksomfang", OFTInteger);

      addSimpleType(poTypes, "SAKSTYPE", "sakstype", OFTInteger);

      addSimpleType(poTypes, "SALINITET", "salinitet", OFTInteger);

      addSimpleType(poTypes, "SAT_KOM_ID", "satellittkommunikasjonsId", OFTString);

      addSimpleType(poTypes, "SCANNEROPPLØSNING", "scanneroppløsning", OFTReal);

      addSimpleType(poTypes, "SEDDYBDEME", "sedDybdeMeter", OFTReal);

      addSimpleType(poTypes, "SEDDYBDEMS", "sedDybdeMillisekund", OFTReal);

      addSimpleType(poTypes, "SEDKORNSTR", "sedKornstorrelse", OFTInteger);

      addSimpleType(poTypes, "SEDMEKTME", "sedMektighetMeter", OFTReal);

      addSimpleType(poTypes, "SEDMEKTMS", "sedMektighetMillisekund", OFTReal);

      addSimpleType(poTypes, "SEFRAK_FUNK_KODE", "sefrakFunksjonsKode", OFTInteger);

      addSimpleType(poTypes, "SEFRAK_FUNK_STAT", "sefrakFunksjonsstatus", OFTString);

      addSimpleType(poTypes, "KM_ANTALL", "kulturminneAntall", OFTInteger);

      addSimpleType(poTypes, "KM_BETEGN", "kulturminneBetegnelse", OFTString);

      addSimpleType(poTypes, "KM_DAT", "kulturminneDatering", OFTString);

      addSimpleType(poTypes, "KM_DATKVAL", "kulturminneDateringKvalitet", OFTString);

      addSimpleType(poTypes, "KM_FUNK_NÅ", "kulturminneNåværendeFunksjon", OFTString);

      addSimpleType(poTypes, "KM_FUNK_OP", "kulturminneOpprinneligFunksjon", OFTString);

      addSimpleType(poTypes, "KM_HOVEDGRUPPE", "kulturminneHovedgruppe", OFTString);

      addSimpleType(poTypes, "KM_KATEGORI", "kulturminneKategori", OFTString);

      addSimpleType(poTypes, "KM_MAT", "kulturminneHovedMateriale", OFTString);

      addSimpleType(poTypes, "KM_SYNLIG", "kulturminneSynlig", OFTString);

      addSimpleType(poTypes, "KM_VERNEVERDI", "kulturminneVerneverdi", OFTString);

      addSimpleType(poTypes, "KODDRIFT", "landbruksregBedriftskode", OFTInteger);

      addSimpleType(poTypes, "KOM_KALLSIGNAL", "komKallSignal", OFTString);

      addSimpleType(poTypes, "KOM_KANAL", "komKanal", OFTString);

      addSimpleType(poTypes, "KOMM", "kommunenummer", OFTInteger);

      addSimpleType(poTypes, "KOMM_ALT_AREAL", "kommAlternativtAreal", OFTReal);

      addSimpleType(poTypes, "KOMM_ALT_AREAL2", "kommAlternativtAreal2", OFTReal);

      addSimpleType(poTypes, "KOMMENTAR", "kommentar", OFTString);

      addSimpleType(poTypes, "KOMMENTAR_TYPE", "kommentarType", OFTString);

      addSimpleType(poTypes, "KOMMSEK", "kommuneSekundær", OFTInteger);

      addSimpleType(poTypes, "KOMPONENT", "komponent", OFTString);

      addSimpleType(poTypes, "KONSTA1", "konstantA1", OFTReal);

      addSimpleType(poTypes, "KONSTA2", "konstantA2", OFTReal);

      addSimpleType(poTypes, "KONSTB1", "konstantB1", OFTReal);

      addSimpleType(poTypes, "KONSTB2", "konstantB2", OFTReal);

      addSimpleType(poTypes, "KONSTC1", "konstantC1", OFTReal);

      addSimpleType(poTypes, "KONSTC2", "konstantC2", OFTReal);

      addSimpleType(poTypes, "KONTAKTPERSON", "kontaktperson", OFTString);

      addSimpleType(poTypes, "KOORDKVALKODE", "koordinatkvalitetKode", OFTString);

      addSimpleType(poTypes, "KOPIDATO", "kopidato", OFTDateTime);

      addSimpleType(poTypes, "KOPL_BRU", "koplingBruksområde", OFTString);

      addSimpleType(poTypes, "KOPL_KAT", "koplingskategori", OFTInteger);

      addSimpleType(poTypes, "KOPL_NAV", "koplingsnavn", OFTString);

      addSimpleType(poTypes, "KOPL_TYP", "koplingstype", OFTString);

      addSimpleType(poTypes, "KORTNAVN", "kortnavn", OFTString);

      addSimpleType(poTypes, "KOSTHOLDART", "kostholdArt", OFTString);

      addSimpleType(poTypes, "KOSTHOLDSRÅDTYPE", "kostholdsrådType", OFTInteger);

      addSimpleType(poTypes, "KP", "knutePunkt", OFTInteger);

      addSimpleType(poTypes, "KPANGITTHENSYN", "angittHensyn", OFTInteger);

      addSimpleType(poTypes, "KPAREALFORMÅL", "arealformål", OFTInteger);

      addSimpleType(poTypes, "KPBÅNDLEGGING", "båndlegging", OFTInteger);

      addSimpleType(poTypes, "KPDETALJERING", "detaljering", OFTInteger);

      addSimpleType(poTypes, "KPFARE", "fare", OFTInteger);

      addSimpleType(poTypes, "KPGJENNOMFØRING", "gjennomføring", OFTInteger);

      addSimpleType(poTypes, "KPINFRASTRUKTUR", "infrastruktur", OFTInteger);

      addSimpleType(poTypes, "KPINFRASTRUKTURLINJE", "infrastrukturLinje", OFTInteger);

      addSimpleType(poTypes, "KPJURLINJE", "juridisklinje", OFTInteger);

      addSimpleType(poTypes, "KPRESTENAVN", "prestegjeldnavn", OFTString);

      addSimpleType(poTypes, "KPRESTENR", "prestegjeldnummer", OFTInteger);

      addSimpleType(poTypes, "KPROSTINAVN", "prostinavn", OFTString);

      addSimpleType(poTypes, "KPROSTINR", "prostinummer", OFTInteger);

      addSimpleType(poTypes, "KPSIKRING", "sikring", OFTInteger);

      addSimpleType(poTypes, "KPSTØY", "støy", OFTInteger);

      addSimpleType(poTypes, "KRAFTVERKTYP", "kraftverktype", OFTString);

      addSimpleType(poTypes, "KRETSNAVN", "kretsnavn", OFTString);

      addSimpleType(poTypes, "KRETSNUMMER", "kretsnummer", OFTString);

      addSimpleType(poTypes, "KRETSTYPEKODE", "kretstypekode", OFTString);

      addSimpleType(poTypes, "KRETSTYPENAVN", "kretstypenavn", OFTString);

      addSimpleType(poTypes, "KULT_HIST_INT", "kulturhistoriskInteresse", OFTString);

      addSimpleType(poTypes, "KVIKKLEIRESVURD", "stabilitetVurderingKvikkleire", OFTInteger);

      addSimpleType(poTypes, "KYSTKONSTRUKSJONSTYPE", "kystkonstruksjonstype", OFTInteger);

      addSimpleType(poTypes, "KYSTREF", "kystreferanse", OFTString);

      addSimpleType(poTypes, "KYSTTYP", "kysttype", OFTInteger);

      addSimpleType(poTypes, "KYSTVERKSDISTRIKT", "kystverksdistrikt", OFTInteger);

      addSimpleType(poTypes, "LAGRET_DATO", "lagretDato", OFTDate);

      addSimpleType(poTypes, "LAND1", "førsteLand", OFTString);

      addSimpleType(poTypes, "LAND2", "annetLand", OFTString);

      addSimpleType(poTypes, "LANDEMERKEKATEGORI", "landeberkekategori", OFTInteger);

      addSimpleType(poTypes, "LANDKODE", "landkode", OFTString);

      addSimpleType(poTypes, "LATERALMERKETYPE", "lateralmerketype", OFTInteger);

      addSimpleType(poTypes, "LDEL", "landsdelområde", OFTInteger);

      addSimpleType(poTypes, "LEDN_BRU", "ledningbruksområde", OFTString);

      addSimpleType(poTypes, "LEDN_NAV", "ledningsnavn", OFTString);

      addSimpleType(poTypes, "LEDN_TYP", "ledningstype", OFTInteger);

      addSimpleType(poTypes, "LEDNINGSEIER", "ledningseier", OFTString);

      addSimpleType(poTypes, "LEKEREKRTYPE", "lekeRekreasjonstype", OFTString);

      addSimpleType(poTypes, "LENGDE", "lengde", OFTReal);

      addSimpleType(poTypes, "LENGDEENHET", "lengdeenhet", OFTString);

      addSimpleType(poTypes, "LENGDEOVERLAPP", "lengdeoverlapp", OFTInteger);

      addSimpleType(poTypes, "LENGDESEKTORLINJE1", "lengdeSektorlinje1", OFTReal);

      addSimpleType(poTypes, "LENGDESEKTORLINJE2", "lengdeSektorlinje2", OFTReal);

      addSimpleType(poTypes, "LETE_AREAL", "leteareal", OFTReal);

      addSimpleType(poTypes, "LH_BEREDSKAP", "lufthavnBeredskapskode", OFTInteger);

      addSimpleType(poTypes, "LHAREAL", "lufthavnArealer", OFTInteger);

      addSimpleType(poTypes, "LHDISTTYPE", "lufthavndistansetype", OFTInteger);

      addSimpleType(poTypes, "LHELEV", "lufthavnelevasjon", OFTReal);

      addSimpleType(poTypes, "LHFDET", "lufthavnForsvarsObjektDetalj", OFTInteger);

      addSimpleType(poTypes, "LHFM_TYPE", "lufthavnFastmerketype", OFTInteger);

      addSimpleType(poTypes, "LHINST_TYPE", "lufthavnInstrumenteringType", OFTInteger);

      addSimpleType(poTypes, "LHLYS_OPPHØYD_NEDFELT", "lufthavnLysOpphøydNedfelt", OFTString);

      addSimpleType(poTypes, "LHLYSFARGE", "lufthavnlysFarge", OFTInteger);

      addSimpleType(poTypes, "LHLYSRETN", "lufhavnLysretning", OFTInteger);

      addSimpleType(poTypes, "LHLYSTYPE", "lufthavnlystype", OFTInteger);

      addSimpleType(poTypes, "LHSKILTKATEGORI", "lufthavnskiltkatagori", OFTInteger);

      addSimpleType(poTypes, "LHSKILTLYS", "lufthavnskiltlys", OFTString);

      addSimpleType(poTypes, "LHSKILTTYPE", "lufthavnskilttype", OFTInteger);

      addSimpleType(poTypes, "LINEAMENTTYPE", "lineamentType", OFTInteger);

      addSimpleType(poTypes, "LINK", "link", OFTString);

      addSimpleType(poTypes, "LJORDKL", "lokalJordressurs", OFTInteger);

      addSimpleType(poTypes, "LJORDKL_A", "nedklassifiseringLokalJordressurs", OFTInteger);

      addSimpleType(poTypes, "LOK_NAVN", "lokalitetsnavn", OFTString);

      addSimpleType(poTypes, "LOK_NR", "lokalitetsnummer", OFTInteger);

      addSimpleType(poTypes, "LOSLIGHET", "loslighetGrad", OFTInteger);

      addSimpleType(poTypes, "LOSMKORNSTR", "losmKornstorrelse", OFTInteger);

      addSimpleType(poTypes, "LOSMOVERFLATETYPE", "losmOverflateType", OFTInteger);

      addSimpleType(poTypes, "LOVDISP", "dispensasjonType", OFTInteger);

      addSimpleType(poTypes, "LOVREFBESKRIVELSE", "lovreferanseBeskrivelse", OFTString);

      addSimpleType(poTypes, "LOVREFERANSE", "lovreferanseType", OFTInteger);

      addSimpleType(poTypes, "LR_AKTIV", "landbruksregAktiv", OFTInteger);

      addSimpleType(poTypes, "LR_TYPE", "landbruksregType", OFTInteger);

      addSimpleType(poTypes, "LRV", "vannstandLavestRegulert", OFTReal);

      addSimpleType(poTypes, "LUFTHAVNHINDERTREGRUPPE", "lufthavnhinderTregruppe", OFTString);

      addSimpleType(poTypes, "LVANN", "vannstandLavestRegistrert", OFTReal);

      addSimpleType(poTypes, "LYSHØYDE", "lyshøyde", OFTReal);

      addSimpleType(poTypes, "LØPENR", "bruksenhetLøpenr", OFTInteger);

      addSimpleType(poTypes, "MAGASINNR", "magasinNr", OFTInteger);

      addSimpleType(poTypes, "MAKSHØYDE", "makshøyde", OFTReal);

      addSimpleType(poTypes, "MAKSIMALREKKEVIDDE", "maksimalRekkevidde", OFTReal);

      addSimpleType(poTypes, "MAKSSNØHØYDE", "maksSnøhøyde", OFTInteger);

      addSimpleType(poTypes, "MANGELMATRIKKELFØRINGSKRAV", "mangelMatrikkelføringskrav", OFTString);

      addSimpleType(poTypes, "MARKID", "jordregisterMarkslagKobling", OFTInteger);

      addSimpleType(poTypes, "MARKSLAGAVGRTYPE", "markslagAvgrensingType", OFTInteger);

      addSimpleType(poTypes, "MASSEENHET", "masseenhet", OFTString);

      addSimpleType(poTypes, "MATERIALE", "materialeBolt", OFTInteger);

      addSimpleType(poTypes, "MATERIALE_YTTERV", "materialeYttervegg", OFTInteger);

      addSimpleType(poTypes, "MATR_KODE", "materiellkode", OFTString);

      addSimpleType(poTypes, "MATRIKKELKOMMUNE", "matrikkelkommune", OFTInteger);

      addSimpleType(poTypes, "MATRTYPE", "materialType", OFTInteger);

      addSimpleType(poTypes, "MATRUNTYPE", "materialUndertype", OFTString);

      addSimpleType(poTypes, "MAX_ELEMENT_PKT", "maksAntallPunktGeometritype1", OFTInteger);

      addSimpleType(poTypes, "MAX_OBJEKT_PKT", "maksAntallPunktGeometritype2", OFTInteger);

      addSimpleType(poTypes, "MAX_REF_OBJEKT", "maksAntallGeometriReferanse", OFTInteger);

      addSimpleType(poTypes, "MAX-AVVIK", "maksimaltAvvik", OFTInteger);

      addSimpleType(poTypes, "MAX-N", "maksimumNord", OFTInteger);

      addSimpleType(poTypes, "MAX-Ø", "maksimumØst", OFTInteger);

      addSimpleType(poTypes, "MEDIUM", "medium", OFTString);

      addSimpleType(poTypes, "MEKT50", "mektighetFemtiProsent", OFTReal);

      addSimpleType(poTypes, "MERKEFORM", "merkeform", OFTInteger);

      addSimpleType(poTypes, "MERKELISTENUMMER", "merkelistenummer", OFTInteger);

      addSimpleType(poTypes, "MERKEMØNSTER", "merkemønster", OFTInteger);

      addSimpleType(poTypes, "METADATALINK", "metadatalink", OFTString);

      addSimpleType(poTypes, "METALINTYP", "metamorfLinjetype", OFTString);

      addSimpleType(poTypes, "METAMOGRAD", "metamorfGrad", OFTInteger);

      addSimpleType(poTypes, "METER-FRA", "veglenkeMeterFra", OFTInteger);

      addSimpleType(poTypes, "METER-TIL", "veglenkeMeterTil", OFTInteger);

      addSimpleType(poTypes, "MGENHETBESKRIV", "mgEnhetBeskrivelse", OFTString);

      addSimpleType(poTypes, "MGENHETOPPLOSN", "mgEnhetOpplosning", OFTInteger);

      addSimpleType(poTypes, "MGINSTRUMENT", "mgInstrument", OFTString);

      addSimpleType(poTypes, "MGLINJENR", "mgLinjenummer", OFTString);

      addSimpleType(poTypes, "MGPOSNR", "mgPosisjonnummer", OFTInteger);

      addSimpleType(poTypes, "MGTOKTNR", "mgToktnummer", OFTString);

      addSimpleType(poTypes, "MILITÆRØVELSETYPE", "militærøvelsetype", OFTInteger);

      addSimpleType(poTypes, "MILJOTIL", "miljøtiltak", OFTInteger);

      addSimpleType(poTypes, "MINHØYDE", "minhøyde", OFTReal);

      addSimpleType(poTypes, "MIN-N", "minimumNord", OFTInteger);

      addSimpleType(poTypes, "MIN-Ø", "minimumØst", OFTInteger);

      addSimpleType(poTypes, "MYNDIGHET", "vedtaksmyndighet", OFTString);

      addSimpleType(poTypes, "MYR", "myrklassifikasjon", OFTInteger);

      addSimpleType(poTypes, "MÅLEMETODE", "målemetode", OFTInteger);

      addSimpleType(poTypes, "MÅLESTOKK", "målestokk", OFTInteger);

      addSimpleType(poTypes, "MÅLTALL", "måltall", OFTReal);

      addSimpleType(poTypes, "NASJONALTOPPMERKETYPE", "nasjonalToppmerketype", OFTInteger);

      addSimpleType(poTypes, "NASJVIKTIG", "rastoffViktighetOmfang", OFTString);

      addSimpleType(poTypes, "NAVIGASJONSINSTALLASJONSEIER", "navigasjonsinstallasjonseier", OFTString);

      addSimpleType(poTypes, "NAVLYS_KARAKTER", "navigasjonslyskarakter", OFTInteger);

      addSimpleType(poTypes, "NAVLYSTYPE", "navlysType", OFTInteger);

      addSimpleType(poTypes, "NAVN", "navn", OFTString);

      addSimpleType(poTypes, "NAVNTYPE", "navnetype", OFTInteger);

      addSimpleType(poTypes, "NEDSENKETKANTSTEIN", "nedsenketKantstein", OFTString);

      addSimpleType(poTypes, "NEDSTENGT_DATO", "nedstengtDato", OFTDate);

      addSimpleType(poTypes, "NETT_NIV", "ledningsnettNivå", OFTString);

      addSimpleType(poTypes, "NEVNER", "nevner", OFTReal);

      addSimpleType(poTypes, "NOMINELLREKKEVIDDE", "nominellRekkevidde", OFTReal);

      addSimpleType(poTypes, "NORD", "nord", OFTInteger);

      addSimpleType(poTypes, "NYMATRIKULERT", "nymatrikulert", OFTString);

      addSimpleType(poTypes, "NÆRINGSGRUPPE", "næringsgruppe", OFTString);

      addSimpleType(poTypes, "NØYAKTIGHET", "nøyaktighet", OFTInteger);

      addSimpleType(poTypes, "NØYAKTIGHETSKLASSE", "nøyaktighetsklasse", OFTInteger);

      addSimpleType(poTypes, "NÅVÆRENDE_AREAL", "nåværendeAreal", OFTReal);

      addSimpleType(poTypes, "OBJTYPE", "objekttypenavn", OFTString);

      addSimpleType(poTypes, "OBSERVERTFLOM", "observertFlom", OFTReal);

      addSimpleType(poTypes, "OBSLINID", "obsLinId", OFTString);

      addSimpleType(poTypes, "OMKRETSINNSJØ", "omkretsInnsjø", OFTInteger);

      addSimpleType(poTypes, "OMRKODE", "reinbeiteområdeID", OFTString);

      addSimpleType(poTypes, "OMRNAVN", "områdenavn", OFTString);

      addSimpleType(poTypes, "OMRTYPE", "dumpefelttype", OFTInteger);

      addSimpleType(poTypes, "OMRÅDEID", "områdeid", OFTInteger);

      addSimpleType(poTypes, "OMTVISTET", "omtvistet", OFTString);

      addSimpleType(poTypes, "OPAREALAVGRTYPE", "operativArealavgrensningtype", OFTInteger);

      addSimpleType(poTypes, "OPERATØR", "petroleumsoperatør", OFTString);

      addSimpleType(poTypes, "OPLAREAL", "arealbruk", OFTInteger);

      addSimpleType(poTypes, "OPLAREALUTDYP", "arealbruksutdyping", OFTString);

      addSimpleType(poTypes, "OPLRESTR", "arealbruksrestriksjoner", OFTInteger);

      addSimpleType(poTypes, "OPLRETNL", "arealbruksretningslinjer", OFTInteger);

      addSimpleType(poTypes, "OPPARBEIDING", "opparbeiding", OFTInteger);

      addSimpleType(poTypes, "OPPDATERINGSDATO", "oppdateringsdato", OFTDateTime);

      addSimpleType(poTypes, "OPPDRAGSGIVER", "oppdragsgiver", OFTString);

      addSimpleType(poTypes, "OPPGITTAREAL", "oppgittAreal", OFTReal);

      addSimpleType(poTypes, "OPPHAV", "opphav", OFTString);

      addSimpleType(poTypes, "OPPMÅLINGIKKEFULLFØRT", "oppmålingIkkeFullført", OFTString);

      addSimpleType(poTypes, "OPPMÅLTKOTE", "oppmåltKote", OFTReal);

      addSimpleType(poTypes, "OPPMÅLTÅR", "oppmåltÅr", OFTInteger);

      addSimpleType(poTypes, "OPPRETTET_AAR", "opprettetÅr", OFTDate);

      addSimpleType(poTypes, "OPPRINNELIGBILDEFORMAT", "bildeType", OFTString);

      addSimpleType(poTypes, "OPPRINNELIGBILDESYS", "BildeSystem", OFTInteger);

      addSimpleType(poTypes, "OPPRINNELIGSOSIALTMILJØ", "opprinneligSosialtMiljø", OFTInteger);

      addSimpleType(poTypes, "OPPRINNELSE", "opprinnelse", OFTString);

      addSimpleType(poTypes, "OPPSTARTSÅR", "oppstartsår", OFTDate);

      addSimpleType(poTypes, "OPPTAKSMETODE", "opptaksmetode", OFTInteger);

      addSimpleType(poTypes, "OPPVARMING", "oppvarming", OFTString);

      addSimpleType(poTypes, "ORGANISK", "organiskAndel", OFTInteger);

      addSimpleType(poTypes, "ORGNR", "organsisasjonsnummer", OFTInteger);

      addSimpleType(poTypes, "ORIENTERINGSDATA", "orienteringsdata", OFTString);

      addSimpleType(poTypes, "ORIENTERINGSMETODE", "orienteringsmetode", OFTInteger);

      addSimpleType(poTypes, "ORIGINALDATAVERT", "originalDatavert", OFTString);

      addSimpleType(poTypes, "ORIGO-N", "origoNord", OFTInteger);

      addSimpleType(poTypes, "ORIGO-Ø", "origoØst", OFTInteger);

      addSimpleType(poTypes, "OVERGRUPPE", "overgruppeNavn", OFTString);

      addSimpleType(poTypes, "PBTILTAK", "tiltakstype", OFTInteger);

      addSimpleType(poTypes, "PETLITOKODE", "petrofLitologi", OFTString);

      addSimpleType(poTypes, "PETMETAKODE", "petrofMetamorfose", OFTString);

      addSimpleType(poTypes, "PETROLEUM_KOORD_STATUS", "petroleumKoordinatstatus", OFTString);

      addSimpleType(poTypes, "PETROLEUMLEDNINGFUNKSJON", "petroleumsledningsfunksjon", OFTString);

      addSimpleType(poTypes, "PETROLEUMLEDNINGTYPE", "petroleumsledningstype", OFTString);

      addSimpleType(poTypes, "PETROLEUMSANDEL", "petroleumsandel", OFTReal);

      addSimpleType(poTypes, "PETROLEUMSDATAKILDE", "petroleumsdatakilde", OFTString);

      addSimpleType(poTypes, "PETROLEUMSFELTNAVN", "petroleumsfeltnavn", OFTString);

      addSimpleType(poTypes, "PETROLEUMSFELTTYPE", "petroleumsfelttype", OFTString);

      addSimpleType(poTypes, "PETROLEUMSPARTNERE", "petroleumspartnere", OFTString);

      addSimpleType(poTypes, "PETSTRATKODE", "petrofStratigrafi", OFTString);

      addSimpleType(poTypes, "PILARKATEGORI", "pilarkategori", OFTInteger);

      addSimpleType(poTypes, "PIXEL-STØRR", "pixelstørrelse", OFTReal);

      addSimpleType(poTypes, "PLANBEST", "planbestemmelse", OFTInteger);

      addSimpleType(poTypes, "PLANERING", "planeringsgrad", OFTInteger);

      addSimpleType(poTypes, "PLANID", "planidentifikasjon", OFTString);

      addSimpleType(poTypes, "PLANNAVN", "plannavn", OFTString);

      addSimpleType(poTypes, "FORSLAGSSTILLERTYPE", "forslagsstillerType", OFTInteger);

      addSimpleType(poTypes, "PLANSTAT", "planstatus", OFTInteger);

      addSimpleType(poTypes, "PLANTYPE", "plantype", OFTInteger);

      addSimpleType(poTypes, "PLASS", "plasseringskode", OFTInteger);

      addSimpleType(poTypes, "PLFMERK", "oppstillingplattformmerking", OFTInteger);

      addSimpleType(poTypes, "PLOGSJIKTTEKSTUR", "plogsjiktTekstur", OFTInteger);

      addSimpleType(poTypes, "POBS", "observasjonstype", OFTInteger);

      addSimpleType(poTypes, "POLITIDISTRIKTID", "politidistriktId", OFTInteger);

      addSimpleType(poTypes, "POS_KVAL", "posisjonKvalitet", OFTInteger);

      addSimpleType(poTypes, "POS_TYPE", "posisjonType", OFTInteger);

      addSimpleType(poTypes, "BITS_PR_PIXEL", "bitsPrPixel", OFTInteger);

      addSimpleType(poTypes, "POSTNAVN", "poststedsnavn", OFTString);

      addSimpleType(poTypes, "POSTNR", "postnummer", OFTInteger);

      addSimpleType(poTypes, "PREPARERING", "løypepreparering", OFTString);

      addSimpleType(poTypes, "PRIMÆRSTREKNINGSNUMMER", "primærstrekningsnummer", OFTInteger);

      addSimpleType(poTypes, "PRIOMR", "prioritetområde", OFTString);

      addSimpleType(poTypes, "PRIORITET", "kulturlandskapPrioritet", OFTString);

      addSimpleType(poTypes, "PRIVAT_KLOAKKR", "privatKloakkRensing", OFTInteger);

      addSimpleType(poTypes, "PRODUKT", "produkt", OFTString);

      addSimpleType(poTypes, "PRODUKT_FULLT_NAVN", "produktFullstendigNavn", OFTString);

      addSimpleType(poTypes, "PRODUKTGRUPPE", "produktgruppe", OFTString);

      addSimpleType(poTypes, "PRODUSENT", "geodataprodusent", OFTString);

      addSimpleType(poTypes, "PROJEK", "projeksjon", OFTString);

      addSimpleType(poTypes, "PROSELV", "prosentElv", OFTReal);

      addSimpleType(poTypes, "PROSESS_HISTORIE", "prosesshistorie", OFTString);

      addSimpleType(poTypes, "PROSHAV", "prosentHav", OFTReal);

      addSimpleType(poTypes, "PROSINNSJØ", "prosentInnsjø", OFTReal);

      addSimpleType(poTypes, "PROSJEKTNAVN", "prosjektnavn", OFTString);

      addSimpleType(poTypes, "PROSJEKTSTART", "prosjektstartår", OFTInteger);

      addSimpleType(poTypes, "PROSLAND", "prosentLand", OFTReal);

      addSimpleType(poTypes, "PROSTINUMMER", "prostinummer", OFTInteger);

      addSimpleType(poTypes, "PROVEMATR", "proveMaterial", OFTString);

      addSimpleType(poTypes, "PTYPE", "punktType", OFTString);

      addSimpleType(poTypes, "PUKKVERKTYPE", "pukkverktype", OFTInteger);

      addSimpleType(poTypes, "PUMPER_NØDSTR", "pumperNødstrøm", OFTString);

      addSimpleType(poTypes, "PUMPES_VANNET", "pumperVannet", OFTString);

      addSimpleType(poTypes, "PUNKTBESKR", "punktBeskrivelse", OFTString);

      addSimpleType(poTypes, "PUNKTFESTE", "punktfeste", OFTString);

      addSimpleType(poTypes, "PÅVIRKNINGSGRAD", "påvirkningsgrad", OFTInteger);

      addSimpleType(poTypes, "R_FNR", "forekomstNummer", OFTInteger);

      addSimpleType(poTypes, "R_LNR", "lokalNummer", OFTInteger);

      addSimpleType(poTypes, "R_ONR", "omrNummer", OFTInteger);

      addSimpleType(poTypes, "R_PNR", "proveNummer", OFTInteger);

      addSimpleType(poTypes, "R_RESERVER", "rastoffReserver", OFTInteger);

      addSimpleType(poTypes, "RACONFREKVENSBÅND", "raconFrekvensbånd", OFTString);

      addSimpleType(poTypes, "RACONKARAKTER", "raconkarakter", OFTString);

      addSimpleType(poTypes, "RACONMORSETEGN", "raconmorsetegn", OFTString);

      addSimpleType(poTypes, "RACONRESPONSINTERVALL", "raconresponsintervall", OFTString);

      addSimpleType(poTypes, "RACONTYPE", "racontype", OFTInteger);

      addSimpleType(poTypes, "RADAR_FYR_TYPE", "radarfyrtype", OFTInteger);

      addSimpleType(poTypes, "RADARREFLEKTOR", "radarReflektor", OFTString);

      addSimpleType(poTypes, "RADARSTASJONSTYPE", "radarstasjonstype", OFTInteger);

      addSimpleType(poTypes, "RADIO_FYR_TYPE", "radiofyrtype", OFTInteger);

      addSimpleType(poTypes, "RADIOAKTIV", "radioaktivitetNiva", OFTInteger);

      addSimpleType(poTypes, "RADIOFYRMODULASJON", "radiofyrmodulasjon", OFTString);

      addSimpleType(poTypes, "RADIUS", "radius", OFTReal);

      addSimpleType(poTypes, "RADRISKOMR", "naturlRadioaktivStraling", OFTInteger);

      addSimpleType(poTypes, "RAPPORTERINGSÅR", "rapporteringsår", OFTDate);

      addSimpleType(poTypes, "REFERANSE", "referanse", OFTString);

      addSimpleType(poTypes, "REFERANSENUMMER", "referansenummer", OFTString);

      addSimpleType(poTypes, "REGFORM", "reguleringsformål", OFTInteger);

      addSimpleType(poTypes, "REGFORMUTDYP", "reguleringsformålsutdyping", OFTString);

      addSimpleType(poTypes, "REGISTRERINGKRETSNR", "registreringKretsnr", OFTInteger);

      addSimpleType(poTypes, "REGISTRERT_DATO", "registrertDato", OFTDate);

      addSimpleType(poTypes, "REGMETOD", "registreringsmetode", OFTInteger);

      addSimpleType(poTypes, "REGULERTHØYDE", "regulertHøyde", OFTReal);

      addSimpleType(poTypes, "REINDRIFTANLTYP", "reindriftsanleggstype", OFTInteger);

      addSimpleType(poTypes, "REINDRIFTKONNAVN", "reindriftKonvensjonsområdenavn", OFTString);

      addSimpleType(poTypes, "REKKEVIDDEGRØNN", "rekkeviddeGrønn", OFTReal);

      addSimpleType(poTypes, "REKKEVIDDEGUL", "rekkeviddeGul", OFTReal);

      addSimpleType(poTypes, "REKKEVIDDEHVIT", "rekkeviddeHvit", OFTReal);

      addSimpleType(poTypes, "REKKEVIDDERØD", "rekkeviddeRød", OFTReal);

      addSimpleType(poTypes, "RENHET", "retningsenhet", OFTInteger);

      addSimpleType(poTypes, "RENOVASJON", "renovasjon", OFTInteger);

      addSimpleType(poTypes, "RESIPIENTTYPE", "resipienttype", OFTString);

      addSimpleType(poTypes, "RESTR_OMR", "restriksjonsområde", OFTString);

      addSimpleType(poTypes, "RESTRIKSJONSTYPE", "restriksjonstype", OFTInteger);

      addSimpleType(poTypes, "RET_SYS", "retningsreferanse", OFTInteger);

      addSimpleType(poTypes, "RETN", "retningsverdi", OFTReal);

      addSimpleType(poTypes, "RETNINGSEKTORLINJE1", "retningSektorlinje1", OFTReal);

      addSimpleType(poTypes, "RETNINGSEKTORLINJE2", "retningSektorlinje2", OFTReal);

      addSimpleType(poTypes, "RISIKOVURDERING", "risikovurdering", OFTString);

      addSimpleType(poTypes, "RKB", "rkb", OFTReal);

      addSimpleType(poTypes, "RKB_TD", "rkbTotaltDyp", OFTReal);

      addSimpleType(poTypes, "ROTASJON", "rotasjon", OFTInteger);

      addSimpleType(poTypes, "RPANGITTHENSYN", "angitthensyn", OFTInteger);

      addSimpleType(poTypes, "RPAREALFORMÅL", "arealformål", OFTInteger);

      addSimpleType(poTypes, "RPBÅNDLEGGING", "båndlegging", OFTInteger);

      addSimpleType(poTypes, "RPDETALJERING", "detaljering", OFTInteger);

      addSimpleType(poTypes, "RPFARE", "fare", OFTInteger);

      addSimpleType(poTypes, "RPGJENNOMFØRING", "gjennomføring", OFTInteger);

      addSimpleType(poTypes, "RPINFRASTRUKTUR", "infrastruktur", OFTInteger);

      addSimpleType(poTypes, "RPJURLINJE", "juridisklinje", OFTInteger);

      addSimpleType(poTypes, "RPJURPUNKT", "juridiskpunkt", OFTInteger);

      addSimpleType(poTypes, "RPPÅSKRIFTTYPE", "påskriftType", OFTInteger);

      addSimpleType(poTypes, "RPSIKRING", "sikring", OFTInteger);

      addSimpleType(poTypes, "RPSTØY", "støy", OFTInteger);

      addSimpleType(poTypes, "RSL_JREG", "referansesystemForLandskapJordbruksregioner", OFTString);

      addSimpleType(poTypes, "RSL_REG", "referansesystemForLandskapRegioner", OFTString);

      addSimpleType(poTypes, "RSL_UREG", "referansesystemForLandskapUReg", OFTString);

      addSimpleType(poTypes, "RTALLHØY", "reintallHøyeste", OFTInteger);

      addSimpleType(poTypes, "RTALLVEDTAK", "reintallVedtak", OFTString);

      addSimpleType(poTypes, "RULLEBANEDISTANSETYPE", "rullebanedistansetype", OFTInteger);

      addSimpleType(poTypes, "RULLEBANERETNING", "rullebaneretning", OFTInteger);

      addSimpleType(poTypes, "RUTEBREDDE", "rutebredde", OFTInteger);

      addSimpleType(poTypes, "RUTEFØLGER", "ruteFølger", OFTString);

      addSimpleType(poTypes, "RUTEMERKING", "ruteMerking", OFTString);

      addSimpleType(poTypes, "RUTENETTYPE", "rutenettype", OFTString);

      addSimpleType(poTypes, "RUTENR", "rutenummer", OFTString);

      addSimpleType(poTypes, "SEFRAK_TILTAK", "sefrakTiltak", OFTInteger);

      addSimpleType(poTypes, "SEFRAKBREDDE", "sefrakbredde", OFTInteger);

      addSimpleType(poTypes, "SEFRAKKOMMUNE", "sefrakKommune", OFTInteger);

      addSimpleType(poTypes, "SEFRAKLENGDE", "sefraklengde", OFTInteger);

      addSimpleType(poTypes, "SEIL_BREDDE", "seilingsbredde", OFTReal);

      addSimpleType(poTypes, "SEIL_DYBDE", "seilingsdybde", OFTReal);

      addSimpleType(poTypes, "SEKSJONERT", "seksjonert", OFTString);

      addSimpleType(poTypes, "SEKTORTEKST", "sektortekst", OFTString);

      addSimpleType(poTypes, "SEKUNDÆRSTREKNINGSNUMMER", "sekundærstrekningsnummer", OFTInteger);

      addSimpleType(poTypes, "SENTRUMSSONENAVN", "sentrumssonenavn", OFTString);

      addSimpleType(poTypes, "SENTRUMSSONENUMMER", "sentrumssonenummer", OFTInteger);

      addSimpleType(poTypes, "SEPTIKTANK", "septiktank", OFTString);

      addSimpleType(poTypes, "SERIEKODE1", "serie1", OFTString);

      addSimpleType(poTypes, "SERIEKODE2", "serie2", OFTString);

      addSimpleType(poTypes, "SERIEKODE3", "serie3", OFTString);

      addSimpleType(poTypes, "SERVMERK", "servituttMerknad", OFTString);

      addSimpleType(poTypes, "SERVTYPE", "servituttType", OFTString);

      addSimpleType(poTypes, "SESOMR", "reindriftSesongområde", OFTInteger);

      addSimpleType(poTypes, "SFOTRUTETYPE", "spesialFotrutetype", OFTString);

      addSimpleType(poTypes, "SIDEOVERLAPP", "sideoverlapp", OFTInteger);

      addSimpleType(poTypes, "SIGNALGRUPPE", "signalgruppe", OFTString);

      addSimpleType(poTypes, "SIGNALNR", "signalnummer", OFTString);

      addSimpleType(poTypes, "SIGNALPERIODE", "signalperiode", OFTString);

      addSimpleType(poTypes, "SIGNALSEKVENS", "signalsekvens", OFTString);

      addSimpleType(poTypes, "SIGNH", "signalHøyde", OFTReal);

      addSimpleType(poTypes, "SIGNHREF", "signalHøydeRef", OFTString);

      addSimpleType(poTypes, "SIGNTYPE", "signalType", OFTString);

      addSimpleType(poTypes, "SIKKERÅR", "ledningsalderReferanse", OFTInteger);

      addSimpleType(poTypes, "SIKTEDYP", "sikteDyp", OFTInteger);

      addSimpleType(poTypes, "SIST_VURDERT_AAR", "sistVurdertÅr", OFTDate);

      addSimpleType(poTypes, "SISTBEFART", "sisteBefaringsdato", OFTInteger);

      addSimpleType(poTypes, "SJØ_RESTRIKSJON", "sjørestriksjon", OFTInteger);

      addSimpleType(poTypes, "SJØ_SIGFRQ", "sjøsignalfrekvens", OFTInteger);

      addSimpleType(poTypes, "SJØ_STATUS", "sjøstatus", OFTInteger);

      addSimpleType(poTypes, "SJØ_TRAFIKK", "sjøtrafikk", OFTInteger);

      addSimpleType(poTypes, "SJØMERKEFARGE", "sjømerkefarge", OFTInteger);

      addSimpleType(poTypes, "SJØMERKESYSTEM", "sjømerkesystem", OFTInteger);

      addSimpleType(poTypes, "SKAL_AVGR_BYGN", "skalAvgrenseBygning", OFTString);

      addSimpleType(poTypes, "SKALAENHET", "skalaenhet", OFTString);

      addSimpleType(poTypes, "SKILTGRUPPE", "skiltgruppe", OFTString);

      addSimpleType(poTypes, "SKILØYPETYPE", "skiløypetype", OFTInteger);

      addSimpleType(poTypes, "SKJERMINGFUNK", "skjermingsfunksjon", OFTString);

      addSimpleType(poTypes, "SKOG", "jordregisterSkogtype", OFTInteger);

      addSimpleType(poTypes, "SKOGREIS", "jordregisterSkogreisningsmark", OFTInteger);

      addSimpleType(poTypes, "SKOLEKRETSTYPE", "skolekretsnavn", OFTString);

      addSimpleType(poTypes, "SKREDALDERBEST", "skredAlderBestemmelse", OFTString);

      addSimpleType(poTypes, "SKREDBESKRIVELSE", "skredBeskrivelse", OFTString);

      addSimpleType(poTypes, "SKREDBREDDE", "skredBredde", OFTInteger);

      addSimpleType(poTypes, "SKREDEVAKUERING", "skredEvakuering", OFTInteger);

      addSimpleType(poTypes, "SKREDFALLHØYDE", "skredFallhoyde", OFTInteger);

      addSimpleType(poTypes, "SKREDFAREGR_KL", "skredFaregradKlasse", OFTString);

      addSimpleType(poTypes, "SKREDFAREGRADSCORE", "skredFaregradScore", OFTInteger);

      addSimpleType(poTypes, "SKREDFAREVURD", "snoSteinSkredfareVurdering", OFTInteger);

      addSimpleType(poTypes, "SKREDKONSSCORE", "skredSkadKonsekvensScore", OFTInteger);

      addSimpleType(poTypes, "SKREDKVALKARTLEGGING", "skredKvalKartlegging", OFTInteger);

      addSimpleType(poTypes, "SKREDLENGDE", "skredLengde", OFTInteger);

      addSimpleType(poTypes, "SKREDMALEMETODE", "skredMalemetode", OFTInteger);

      addSimpleType(poTypes, "SKREDOBSGUID", "skredObservasjonGUID", OFTInteger);

      addSimpleType(poTypes, "SKREDOMKOMNE", "skredAntallOmkomne", OFTInteger);

      addSimpleType(poTypes, "SKREDOMRID", "skredOmrID", OFTInteger);

      addSimpleType(poTypes, "SKREDOMRNAVN", "skredOmrNavn", OFTString);

      addSimpleType(poTypes, "SKREDREDNING", "skredRedning", OFTInteger);

      addSimpleType(poTypes, "SKREDRISIKO_KL", "skredRisikoKvikkleireKlasse", OFTInteger);

      addSimpleType(poTypes, "SKREDSKADEANNEN", "skredSkadeAnnen", OFTInteger);

      addSimpleType(poTypes, "SKREDSKADEOBJEKTER", "skredSkadeObjekter", OFTInteger);

      addSimpleType(poTypes, "SKREDSKADESAMFERDSEL", "skredSkadeSamferdsel", OFTInteger);

      addSimpleType(poTypes, "SKREDSKADETYPE", "skredSkadType", OFTInteger);

      addSimpleType(poTypes, "SKREDSKADKONS_KL", "skredSkadeKonsekvensKlasse", OFTInteger);

      addSimpleType(poTypes, "SKREDSTATSANN", "skredStatistikkSannsynlighet", OFTString);

      addSimpleType(poTypes, "SKREDTIDHENDELSE", "skredTidspunktHendelse", OFTString);

      addSimpleType(poTypes, "SKREDTIDUSIKKERH", "skredTidUsikkerhet", OFTString);

      addSimpleType(poTypes, "SKREDTYPE", "skredtype", OFTInteger);

      addSimpleType(poTypes, "SKREDUTLOMRHELNING", "skredUtlosningOmrHelning", OFTInteger);

      addSimpleType(poTypes, "SKREDUTLOPOMRTYPE", "skredUtlopOmrType", OFTInteger);

      addSimpleType(poTypes, "SKREDUTLOSNINGOMRTYPE", "skredUtlosningOmrType", OFTInteger);

      addSimpleType(poTypes, "SKREDVOLUM", "skredVolum", OFTString);

      addSimpleType(poTypes, "SKRETSNAVN", "skolekretsnavn", OFTString);

      addSimpleType(poTypes, "SKRETSNR", "skolekretsnummer", OFTInteger);

      addSimpleType(poTypes, "SKRIFTKODE", "presentasjonskode", OFTInteger);

      addSimpleType(poTypes, "SKYLD", "skyld", OFTReal);

      addSimpleType(poTypes, "SKYVGRINDL", "skyvegrenseInndeling", OFTInteger);

      addSimpleType(poTypes, "SLUSETYP", "sluseType", OFTInteger);

      addSimpleType(poTypes, "SMÅBÅTHAVNFASILITET", "småbåthavnfasilitet", OFTInteger);

      addSimpleType(poTypes, "SNAVN", "stedsnavn", OFTString);

      addSimpleType(poTypes, "SNDATO", "statusdato", OFTDate);

      addSimpleType(poTypes, "SNITT_HØ", "snitthøyde", OFTInteger);

      addSimpleType(poTypes, "SNKILDE", "stedsnavnkilde", OFTString);

      addSimpleType(poTypes, "SNLØPENR", "arkivløpenummer", OFTInteger);

      addSimpleType(poTypes, "SNMERK", "stedsnavnmerknad", OFTString);

      addSimpleType(poTypes, "SNMYND", "stedsnavnVedtaksmyndighet", OFTString);

      addSimpleType(poTypes, "SNR", "seksjonsnummer", OFTInteger);

      addSimpleType(poTypes, "SNREGDATO", "stedsnavnRegistreringsdato", OFTDate);

      addSimpleType(poTypes, "SNSAKSNR", "arkivsaksnummer", OFTInteger);

      addSimpleType(poTypes, "SNSKRSTAT", "stedsnavnSkrivemåtestatus", OFTString);

      addSimpleType(poTypes, "SNSPRÅK", "språk", OFTString);

      addSimpleType(poTypes, "SNTYSTAT", "stedsnavnTypestatus", OFTString);

      addSimpleType(poTypes, "SNØSCOOTERLØYPETYPE", "snøscooterløypeType", OFTString);

      addSimpleType(poTypes, "SOGNNUMMER", "sognnummer", OFTInteger);

      addSimpleType(poTypes, "SONENAUT", "soneNautisk", OFTInteger);

      addSimpleType(poTypes, "SONETYPE", "sonetype", OFTString);

      addSimpleType(poTypes, "SOSIELEMENT", "sosiElementnavn", OFTString);

      addSimpleType(poTypes, "SOSI-NIVÅ", "sosiKompleksitetNivå", OFTInteger);

      addSimpleType(poTypes, "SOSI-VERSJON", "sosiVersjon", OFTString);

      addSimpleType(poTypes, "SP_ABONTRE", "skogbrplanKlassAktueltTreslag", OFTInteger);

      addSimpleType(poTypes, "SP_AGJBON", "skogbrplanKlassAktSnittBon", OFTInteger);

      addSimpleType(poTypes, "SP_ALDER", "skogbrplanBeskrivBestandAlder", OFTInteger);

      addSimpleType(poTypes, "SP_ANDEREG", "skogbrplanTreslagAntTreDaaEReg", OFTInteger);

      addSimpleType(poTypes, "SP_ANDFREG", "skogbrplanTreslagAntTreDaaFReg", OFTInteger);

      addSimpleType(poTypes, "SP_AVOLPRDA", "skogbrplanGrunnlagVolumDaaFelt", OFTReal);

      addSimpleType(poTypes, "SP_AVOLTOT", "skogbrplanGrunnlagVolumBestFelt", OFTInteger);

      addSimpleType(poTypes, "SP_BAREAL", "skogbrplanBeskrivBestandDaa", OFTReal);

      addSimpleType(poTypes, "SP_BERTYPE", "skogbrplanGrunnlagBerType", OFTInteger);

      addSimpleType(poTypes, "SP_BESTDELNR", "skogbrplanBestandDelNr", OFTInteger);

      addSimpleType(poTypes, "SP_BESTNR", "skogbrplanBestandNr", OFTInteger);

      addSimpleType(poTypes, "SP_BEVNE", "skogbrplanTerrengBæreevneBestand", OFTInteger);

      addSimpleType(poTypes, "SP_BMIDDIAM", "skogbrplanBeskrivBestSnittDiam", OFTInteger);

      addSimpleType(poTypes, "SP_BMIDGRFL", "skogbrplanBeskrivBestandSnittM2", OFTInteger);

      addSimpleType(poTypes, "SP_BMIDHO", "skogbrplanBeskrivBestandSnittH", OFTReal);

      addSimpleType(poTypes, "SP_BRATT", "skogbrplanTerrengBestandBratthet", OFTInteger);

      addSimpleType(poTypes, "SP_BTILVPRDA", "skogbrplanTilvekstBeregnDaa", OFTReal);

      addSimpleType(poTypes, "SP_BTILVPROS", "skogbrplanTilvekstBeregnProsent", OFTReal);

      addSimpleType(poTypes, "SP_BVOLPRDA", "skogbrplanTilvekstBeregnM3", OFTReal);

      addSimpleType(poTypes, "SP_DENDR", "skogbrplanAdmDatoEndring", OFTDate);

      addSimpleType(poTypes, "SP_DREG", "skogbrplanAdmDatoEtablering", OFTDate);

      addSimpleType(poTypes, "SP_ELEMTYPE", "skogbrplanFlerKoderElementtype", OFTInteger);

      addSimpleType(poTypes, "SP_FARAND", "skogbrplanFlerKoderArealProsent", OFTInteger);

      addSimpleType(poTypes, "SP_FAREAL", "skogbrplanFlerKoderArealDaa", OFTInteger);

      addSimpleType(poTypes, "SP_FRAND", "skogbrplanFlerKoderSpesBehPros", OFTInteger);

      addSimpleType(poTypes, "SP_FRAREAL", "skogbrplanFlerKoderSpesBehDaa", OFTInteger);

      addSimpleType(poTypes, "SP_GREND", "skogbrplanTeigGrend", OFTInteger);

      addSimpleType(poTypes, "SP_GRFL", "skogbrplanTetthetGrunnflatesum", OFTInteger);

      addSimpleType(poTypes, "SP_HBAR", "skogbrplanBeskrivBarHøydehkl2", OFTInteger);

      addSimpleType(poTypes, "SP_HKL", "skogbrplanBeskrivHogstklasse", OFTInteger);

      addSimpleType(poTypes, "SP_HLAUV", "skogbrplanBeskrivLauvHøydehkl2", OFTInteger);

      addSimpleType(poTypes, "SP_HOVEDGR", "skogbrplanGrunnlagHovedgruppe", OFTInteger);

      addSimpleType(poTypes, "SP_HOYDE", "skogbrplanTetthetMHøyde", OFTInteger);

      addSimpleType(poTypes, "SP_IMPANDEL", "skogbrplanKlassImpProsent", OFTInteger);

      addSimpleType(poTypes, "SP_IMPTYPE", "skogbrplanKlassImpType", OFTInteger);

      addSimpleType(poTypes, "SP_LILEN", "skogbrplanTerrengLiLengde", OFTInteger);

      addSimpleType(poTypes, "SP_MINTRSP", "skogbrplanTerrengMinTranspUtst", OFTInteger);

      addSimpleType(poTypes, "SP_PBONTRE", "skogbrplanKlassPotTreslag", OFTInteger);

      addSimpleType(poTypes, "SP_PGJBON", "skogbrplanKlassPotSnittBon", OFTInteger);

      addSimpleType(poTypes, "SP_PRIO", "skogbrplanTiltakProritet", OFTInteger);

      addSimpleType(poTypes, "SP_REG", "skogbrplanGrunnlagRegion", OFTInteger);

      addSimpleType(poTypes, "SP_SJIKT", "skogbrplanBeskrivSjiktning", OFTInteger);

      addSimpleType(poTypes, "SP_SKOGTYP", "skogbrplanBeskrivSkogtype", OFTInteger);

      addSimpleType(poTypes, "SP_SUNNH", "skogbrplanBeskrivSunnhet", OFTInteger);

      addSimpleType(poTypes, "SP_SVPROS", "skogbrplanGrunnlagSvinnProsent", OFTInteger);

      addSimpleType(poTypes, "SP_TAKSTTYPE", "skogbrplanGrunnlagTaksttype", OFTInteger);

      addSimpleType(poTypes, "SP_TARAND", "skogbrplanTiltakProsent", OFTInteger);

      addSimpleType(poTypes, "SP_TAREAL", "skogbrplanTiltakAreal", OFTReal);

      addSimpleType(poTypes, "SP_TEIGNR", "skogbrplanTeigNr", OFTInteger);

      addSimpleType(poTypes, "SP_TERJEVN", "skogbrplanTerrengJevnhet", OFTInteger);

      addSimpleType(poTypes, "SP_TILT", "skogbrplanTiltakBestand", OFTInteger);

      addSimpleType(poTypes, "SP_TILVKOR", "skogbrplanGrunnlagTilvekstkorr", OFTInteger);

      addSimpleType(poTypes, "SP_TNAVN", "skogbrplanTeigNavn", OFTString);

      addSimpleType(poTypes, "SP_TOTVOL", "skogbrplanTilvekstVolumBestand", OFTInteger);

      addSimpleType(poTypes, "SP_TREEREG", "skogbrplanBeskrivTreERegulering", OFTInteger);

      addSimpleType(poTypes, "SP_TREFREG", "skogbrplanBeskrivTreFRegulering", OFTInteger);

      addSimpleType(poTypes, "SP_TRESLAG", "skogbrplanTreslag", OFTInteger);

      addSimpleType(poTypes, "SP_TRESLHO", "skogbrplanTreslagHøyde", OFTInteger);

      addSimpleType(poTypes, "SP_VOLAND", "skogbrplanTreslagProsent", OFTInteger);

      addSimpleType(poTypes, "SP_VOLKORR", "skogbrplanTreslagKorrVolumUBark", OFTInteger);

      addSimpleType(poTypes, "SP_VOLSALG", "skogbrplanTreslagSalgsvolumUBark", OFTInteger);

      addSimpleType(poTypes, "SP_VOLUKORR", "skogbrplanTreslagUkorrVolumUBark", OFTInteger);

      addSimpleType(poTypes, "SP_AAR", "skogbrplanTiltakÅr", OFTInteger);

      addSimpleType(poTypes, "SPERRING", "sperring", OFTString);

      addSimpleType(poTypes, "SPES_SKILØYPETYPE", "spesialSkiløypetype", OFTString);

      addSimpleType(poTypes, "SPESIALMERKETYPE", "spesialmerketype", OFTInteger);

      addSimpleType(poTypes, "SPESIALSYKKELRUTETYPE", "spesialsykkelrutetype", OFTString);

      addSimpleType(poTypes, "SPOR_HASTIGHET", "sporhastighet", OFTInteger);

      addSimpleType(poTypes, "SPORANTALL", "sporantall", OFTString);

      addSimpleType(poTypes, "SPORAVGRENINGSNR", "sporavgreningsnummer", OFTString);

      addSimpleType(poTypes, "SPORAVGRENINGSPUNKTNR", "sporavgreningspunktnummer", OFTString);

      addSimpleType(poTypes, "SPORAVGRENINGSPUNKTTYPE", "sporavgreningspunkttype", OFTString);

      addSimpleType(poTypes, "SPORAVGRENINGSTYPE", "sporavgreningstype", OFTString);

      addSimpleType(poTypes, "SPORKM", "sporKilometer", OFTReal);

      addSimpleType(poTypes, "SPORNUMMER", "spornummer", OFTString);

      addSimpleType(poTypes, "SPORPUNKTNUMMER", "sporpunktnummer", OFTString);

      addSimpleType(poTypes, "SPORPUNKTTYPE", "sporpunkttype", OFTString);

      addSimpleType(poTypes, "SPORTYPE", "sportype", OFTString);

      addSimpleType(poTypes, "SSR-ID", "ssrId", OFTInteger);

      addSimpleType(poTypes, "SSR-OBJID", "objId", OFTInteger);

      addSimpleType(poTypes, "STANDARDENHET", "standardenhet", OFTString);

      addSimpleType(poTypes, "STASJONSFORMÅL", "stasjonsformål", OFTString);

      addSimpleType(poTypes, "STASJONSNR", "stasjonsnummer", OFTInteger);

      addSimpleType(poTypes, "STASJONSPARAMETER", "stasjonsparameter", OFTInteger);

      addSimpleType(poTypes, "STASJONSTYPE", "stasjonstype", OFTString);

      addSimpleType(poTypes, "STASJONTYP", "stasjonstype", OFTString);

      addSimpleType(poTypes, "STAT", "typeStatus", OFTInteger);

      addSimpleType(poTypes, "STATUS", "status", OFTString);

      addSimpleType(poTypes, "STED", "sted", OFTString);

      addSimpleType(poTypes, "STED_VERIF", "stedfestingVerifisert", OFTString);

      addSimpleType(poTypes, "STENGESDATO", "stengesDato", OFTDate);

      addSimpleType(poTypes, "STORBUE", "storbue", OFTInteger);

      addSimpleType(poTypes, "STREKNINGSNUMMER", "strekningsnummer", OFTInteger);

      addSimpleType(poTypes, "STRENG", "generellTekststreng", OFTString);

      addSimpleType(poTypes, "STRIPENUMMER", "stripenummer", OFTString);

      addSimpleType(poTypes, "STRUKTUROVERBIKKET", "strukturOverbikket", OFTString);

      addSimpleType(poTypes, "STRUKTURPUNKTTYPE", "strukturPunkttype", OFTInteger);

      addSimpleType(poTypes, "STRØMHAST", "strømhastighet", OFTReal);

      addSimpleType(poTypes, "STRØMRETN", "strømretning", OFTInteger);

      addSimpleType(poTypes, "STØYENHET", "støyenhet", OFTString);

      addSimpleType(poTypes, "STØYINTERVALL", "støyintervall", OFTInteger);

      addSimpleType(poTypes, "STØYKILDE", "støykilde", OFTString);

      addSimpleType(poTypes, "STØYKILDEIDENTIFIKASJON", "Støykildeidentifikasjon", OFTString);

      addSimpleType(poTypes, "STØYKILDENAVN", "støykildenavn", OFTString);

      addSimpleType(poTypes, "STØYMETODE", "støymetode", OFTString);

      addSimpleType(poTypes, "STØYNIVÅ", "støynivå", OFTInteger);

      addSimpleType(poTypes, "STØYSONEKATEGORI", "støysonekategori", OFTString);

      addSimpleType(poTypes, "SUM_ALT_AREAL", "sumAlternativtAreal", OFTReal);

      addSimpleType(poTypes, "SUM_ALT_AREAL2", "sumAlternativtAreal2", OFTReal);

      addSimpleType(poTypes, "SUM_ANTALLBOENH", "sumAntallBoenheter", OFTInteger);

      addSimpleType(poTypes, "SUM_BRUKSARTOT", "sumBruksarealTotalt", OFTReal);

      addSimpleType(poTypes, "SUM_BRUKSTILANN", "sumBruksarealTilAnnet", OFTReal);

      addSimpleType(poTypes, "SUM_BRUKSTILBOL", "sumBruksarealTilBolig", OFTReal);

      addSimpleType(poTypes, "SYKKELRUTETYPE", "sykkelrutetype", OFTInteger);

      addSimpleType(poTypes, "SYNBARHET", "synbarhet", OFTInteger);

      addSimpleType(poTypes, "SYSKODE", "referansesystemKode", OFTInteger);

      addSimpleType(poTypes, "TAKFORM", "takform", OFTInteger);

      addSimpleType(poTypes, "TAKSKJEGG", "takskjegg", OFTInteger);

      addSimpleType(poTypes, "TAKTEKKING", "taktekking", OFTInteger);

      addSimpleType(poTypes, "TDIM-BREDDE", "tekstTegnbredde", OFTReal);

      addSimpleType(poTypes, "TDIM-HØYDE", "tekstTegnhøyde", OFTReal);

      addSimpleType(poTypes, "TEGNFORKL", "tegnforklaring", OFTString);

      addSimpleType(poTypes, "TEGNSETT", "tegnsett", OFTString);

      addSimpleType(poTypes, "TEIGE_ID", "teigEtterSkifteIdent", OFTInteger);

      addSimpleType(poTypes, "TEIGF_ID", "teigFørSkitfeIdent", OFTInteger);

      addSimpleType(poTypes, "TEIGFLEREMATRSAMMEEIER", "teigFlereMatrSammeEier", OFTString);

      addSimpleType(poTypes, "TEIGMEDFLEREMATRENHETER", "teigMedFlereMatrikkelenheter", OFTString);

      addSimpleType(poTypes, "TEIGNR", "jordregisterEiendomTeigNummer", OFTInteger);

      addSimpleType(poTypes, "TEKSTURKODE1", "teksturkode", OFTString);

      addSimpleType(poTypes, "TEKSTURKODE2", "teksturkode2", OFTString);

      addSimpleType(poTypes, "TEKSTURKODE3", "teksturkode3", OFTString);

      addSimpleType(poTypes, "TELEFAXNR", "telefaxnummer", OFTInteger);

      addSimpleType(poTypes, "TELEFONNR", "telefonnummer", OFTInteger);

      addSimpleType(poTypes, "TELLER", "teller", OFTReal);

      addSimpleType(poTypes, "TEMAJUST", "geolTemajustering", OFTInteger);

      addSimpleType(poTypes, "TEMAKVAL", "temaKvalitet", OFTString);

      addSimpleType(poTypes, "TERSKELFUNKSJON", "terskelFunksjon", OFTString);

      addSimpleType(poTypes, "TERSKELTYP", "terskelType", OFTString);

      addSimpleType(poTypes, "TETTSTEDNAVN", "tettstednavn", OFTString);

      addSimpleType(poTypes, "TIDOPPHOLDVANN", "tidOppholdVann", OFTInteger);

      addSimpleType(poTypes, "TIDREF", "tidreferanse", OFTString);

      addSimpleType(poTypes, "TIDSANGIVELSE", "tidsangivelse", OFTInteger);

      addSimpleType(poTypes, "TIDSENHET", "tidsenhet", OFTString);

      addSimpleType(poTypes, "TIDSLUTT", "periodeSlutt", OFTDateTime);

      addSimpleType(poTypes, "TIDSPUNKT", "tidspunkt", OFTDateTime);

      addSimpleType(poTypes, "TIDSTART", "periodeStart", OFTDateTime);

      addSimpleType(poTypes, "TILDELT_AREAL", "tildeltAreal", OFTReal);

      addSimpleType(poTypes, "TILDELT_DATO", "tilldeltDato", OFTDate);

      addSimpleType(poTypes, "TILGJENGELIGHETSVURDERING", "tilgjengelighetsvurdering", OFTString);

      addSimpleType(poTypes, "TILLEGG", "flatetillegg", OFTInteger);

      addSimpleType(poTypes, "TILLEGGSAREAL", "tilleggsareal", OFTInteger);

      addSimpleType(poTypes, "TILSPORNODEKILOMETER", "tilSpornodeKilometer", OFTReal);

      addSimpleType(poTypes, "TILSPORNODETEKST", "tilSpornodeTekst", OFTString);

      addSimpleType(poTypes, "TILSPORNODETYPE", "tilSpornodeType", OFTString);

      addSimpleType(poTypes, "TILSYS", "tilKoordinatsystem", OFTInteger);

      addSimpleType(poTypes, "TILTAKNR", "tiltaksnummer", OFTInteger);

      addSimpleType(poTypes, "TINGLYST", "tinglyst", OFTString);

      addSimpleType(poTypes, "TIPPVOLUM", "deponitippVolum", OFTInteger);

      addSimpleType(poTypes, "TOKTID", "toktId", OFTString);

      addSimpleType(poTypes, "TOT_PROD", "totalProduksjon", OFTInteger);

      addSimpleType(poTypes, "TOTALAREALKM2", "totalarealKm2", OFTReal);

      addSimpleType(poTypes, "TOTALBELASTNING", "totalBelastning", OFTInteger);

      addSimpleType(poTypes, "TRAFIKKBELASTNING", "trafikkbelastning", OFTInteger);

      addSimpleType(poTypes, "TRAFIKKFARE", "trafikkfare", OFTString);

      addSimpleType(poTypes, "TRE_D_NIVÅ", "treDNivå", OFTInteger);

      addSimpleType(poTypes, "TRE_TYP", "treType", OFTInteger);

      addSimpleType(poTypes, "TRNORD", "tekstReferansePunktNord", OFTInteger);

      addSimpleType(poTypes, "TRØST", "tekstReferansePunktØst", OFTInteger);

      addSimpleType(poTypes, "TSKOG", "tilleggsopplysningerSkog", OFTInteger);

      addSimpleType(poTypes, "TSKYV", "tekstForskyvning", OFTReal);

      addSimpleType(poTypes, "TSTED", "tettstednummer", OFTInteger);

      addSimpleType(poTypes, "TVIST", "tvist", OFTString);

      addSimpleType(poTypes, "TWYMERK", "taksebaneoppmerking", OFTInteger);

      addSimpleType(poTypes, "TYPE_BR", "trasebreddetype", OFTInteger);

      addSimpleType(poTypes, "TYPE_VANNFOR_ANL", "typeVannforsyningsanlegg", OFTInteger);

      addSimpleType(poTypes, "TYPEDUMPEOMRÅDE", "typeDumpeområde", OFTInteger);

      addSimpleType(poTypes, "TYPEINNSJØ", "typeInnsjø", OFTInteger);

      addSimpleType(poTypes, "TYPESAMFLINJE", "samferdselslinjeType", OFTInteger);

      addSimpleType(poTypes, "TYPESAMFPUNKT", "samferdselspunkt", OFTInteger);

      addSimpleType(poTypes, "UB_ANL_TYP", "utmarkbeiteAnleggstype", OFTInteger);

      addSimpleType(poTypes, "UB_DYRESL", "utmarkbeiteDyreslag", OFTString);

      addSimpleType(poTypes, "UFULLSTENDIGAREAL", "ufullstendigAreal", OFTString);

      addSimpleType(poTypes, "UNDERBYGNINGKONSTR", "underbygningKonstr", OFTInteger);

      addSimpleType(poTypes, "UNDERGRUNN", "undergrunn", OFTString);

      addSimpleType(poTypes, "UNDERLAG", "fastmerkeUnderlag", OFTInteger);

      addSimpleType(poTypes, "UNDERLAGSTYPE", "underlagstype", OFTInteger);

      addSimpleType(poTypes, "UNDERSAMMENFØYNINGSKALBESTÅ", "underSammenføyningSkalBestå", OFTString);

      addSimpleType(poTypes, "UNDERSAMMENFØYNINGSKALUTGÅ", "underSammenføyningSkalUtgå", OFTString);

      addSimpleType(poTypes, "UNDERSOKELSENR", "undersokelseNummer", OFTInteger);

      addSimpleType(poTypes, "UNDERTYPE", "undertypeVersjon", OFTString);

      addSimpleType(poTypes, "UNR", "underNr", OFTInteger);

      addSimpleType(poTypes, "UREGJORDSAMEIE", "uregistrertJordsameie", OFTString);

      addSimpleType(poTypes, "UTEAREAL", "uteoppholdsareal", OFTInteger);

      addSimpleType(poTypes, "UTGÅR_DATO", "utgårDato", OFTDate);

      addSimpleType(poTypes, "UTGÅTT", "utgått", OFTString);

      addSimpleType(poTypes, "UTNTALL", "utnyttingstall", OFTReal);

      addSimpleType(poTypes, "UTNTYP", "utnyttingstype", OFTInteger);

      addSimpleType(poTypes, "UTNYTTBAR_KAP", "utnyttbarMagasinkapasitet", OFTReal);

      addSimpleType(poTypes, "UTSLIPPTYPE", "utslipptype", OFTString);

      addSimpleType(poTypes, "UTV_TILL_NR", "tillatelsesnummer", OFTString);

      addSimpleType(poTypes, "UTV_TILL_TYPE", "utvinningstillatelsestype", OFTString);

      addSimpleType(poTypes, "UTVALGSAK", "utvalgssaksnummer", OFTInteger);

      addSimpleType(poTypes, "UTVALGSMET", "utvalgMetode", OFTString);

      addSimpleType(poTypes, "UUFASILITET", "universellutformingFasilitet", OFTString);

      addSimpleType(poTypes, "VALUTAENHET", "valutaenhet", OFTString);

      addSimpleType(poTypes, "VANNBR", "vannbredde", OFTInteger);

      addSimpleType(poTypes, "VANNFORSYNING", "vannforsyning", OFTInteger);

      addSimpleType(poTypes, "VANNFØRINGMIDLERE", "vannføringMidlere", OFTInteger);

      addSimpleType(poTypes, "VANNFØRINGMINSTE", "vannføringMinste", OFTInteger);

      addSimpleType(poTypes, "VANNFØRINGSTØRST", "vannføringStørst", OFTInteger);

      addSimpleType(poTypes, "VANNLAGR", "vannlagringsevne", OFTInteger);

      addSimpleType(poTypes, "VASSDRAGNAVN", "vassdragsnavn", OFTString);

      addSimpleType(poTypes, "VASSDRAGSNR", "vassdragsnummer", OFTString);

      addSimpleType(poTypes, "VATNLNR", "vatnLøpenummer", OFTInteger);

      addSimpleType(poTypes, "V-DELTA-MAX", "vertikaltDeltaMaksimum", OFTInteger);

      addSimpleType(poTypes, "V-DELTA-MIN", "vertikaltDeltaMinimum", OFTInteger);

      addSimpleType(poTypes, "VEDLIKEH", "vedlikeholdsansvarlig", OFTString);

      addSimpleType(poTypes, "VEDTAK", "vedtakstype", OFTInteger);

      addSimpleType(poTypes, "VEDTAKSDATO", "vedtaksdato", OFTDate);

      addSimpleType(poTypes, "VEGKATEGORI", "vegkategori", OFTString);

      addSimpleType(poTypes, "VEGNUMMER", "vegnummer", OFTInteger);

      addSimpleType(poTypes, "VEGOVERVEG", "vegOverVeg", OFTString);

      addSimpleType(poTypes, "VEGREKKVERKTYPE", "vegrekkverkType", OFTString);

      addSimpleType(poTypes, "VEGSPERRINGTYPE", "vegsperringtype", OFTString);

      addSimpleType(poTypes, "VEGSTATUS", "vegstatus", OFTString);

      addSimpleType(poTypes, "VERDI", "verdi", OFTInteger);

      addSimpleType(poTypes, "VERDI1", "verdi", OFTString);

      addSimpleType(poTypes, "VERDI2", "tilVerdi", OFTString);

      addSimpleType(poTypes, "VERDIANNA", "verdiAnnenUtnyttelseGrunn", OFTReal);

      addSimpleType(poTypes, "VERDIBEITE", "verdiBeiterett", OFTReal);

      addSimpleType(poTypes, "VERDIGRUNN", "verdiGrunn", OFTReal);

      addSimpleType(poTypes, "VERDIJAKT", "verdiJaktrett", OFTReal);

      addSimpleType(poTypes, "VERDISKOG", "verdiSkogProduksjon", OFTReal);

      addSimpleType(poTypes, "VERIFISERINGSDATO", "verifiseringsdato", OFTDateTime);

      addSimpleType(poTypes, "VERN_FORMAL", "verneFormål", OFTString);

      addSimpleType(poTypes, "VERN_LOV", "vernelov", OFTString);

      addSimpleType(poTypes, "VERN_MOT", "vernskogType", OFTInteger);

      addSimpleType(poTypes, "VERN_PARA", "verneparagraf", OFTString);

      addSimpleType(poTypes, "VERNEDATO", "vernedato", OFTDate);

      addSimpleType(poTypes, "VERNEFORM", "verneform", OFTString);

      addSimpleType(poTypes, "VERNEPLAN", "verneplan", OFTInteger);

      addSimpleType(poTypes, "VERNTEMA", "verneTema", OFTInteger);

      addSimpleType(poTypes, "VERNTYPE", "vernetype", OFTString);

      addSimpleType(poTypes, "VERSJON", "versjon", OFTString);

      addSimpleType(poTypes, "VERT_BÆREKONSTR", "vertikalBærekonstruksjon", OFTInteger);

      addSimpleType(poTypes, "VERTNIV", "vertikalnivå", OFTInteger);

      addSimpleType(poTypes, "VFLATE", "delteigKlassifisering", OFTInteger);

      addSimpleType(poTypes, "VFRADATO", "veglenkeFraDato", OFTDate);

      addSimpleType(poTypes, "VIKTIG", "viktighet", OFTInteger);

      addSimpleType(poTypes, "VINDRETN", "vindretning", OFTInteger);

      addSimpleType(poTypes, "VINKELENHET", "vinkelenhet", OFTString);

      addSimpleType(poTypes, "VIRKSOMHET", "typeRastoffVirksomhet", OFTInteger);

      addSimpleType(poTypes, "VISUELLTYDELIGHET", "visuellTydelighet", OFTInteger);

      addSimpleType(poTypes, "VKJORFLT", "feltoversikt", OFTString);

      addSimpleType(poTypes, "VKRETSNAVN", "valgkretsnavn", OFTString);

      addSimpleType(poTypes, "VKRETSNR", "valgkretsnummer", OFTInteger);

      addSimpleType(poTypes, "VLENKEID", "veglenkeIdentifikasjon", OFTInteger);

      addSimpleType(poTypes, "VOLUM_M3", "rastoffVolum", OFTInteger);

      addSimpleType(poTypes, "VOLUMENHET", "volumenhet", OFTString);

      addSimpleType(poTypes, "VOLUMINNSJØ", "volumInnsjø", OFTInteger);

      addSimpleType(poTypes, "VRAKTYP", "vraktype", OFTInteger);

      addSimpleType(poTypes, "VTILDATO", "veglenkeTilDato", OFTDate);

      addSimpleType(poTypes, "VURDERING", "vurdering", OFTString);

      addSimpleType(poTypes, "VURDERTDATO", "vurdertDato", OFTDate);

      addSimpleType(poTypes, "VÆSKETYPE", "petroleumsvæsketype", OFTInteger);

      addSimpleType(poTypes, "WRBKODE", "WRBgruppe", OFTString);

      addSimpleType(poTypes, "YTTERVEGG", "yttervegg", OFTInteger);

      addSimpleType(poTypes, "ØST", "øst", OFTInteger);

      addSimpleType(poTypes, "ÅPNESDATO", "åpnesDato", OFTDate);

      addSimpleType(poTypes, "ÅR", "årstall", OFTInteger);

      addSimpleType(poTypes, "ÅRSTIDBRUK", "årstidbruk", OFTString);

      addSimpleType(poTypes, "VEDTAKENDELIGPLANDATO", "vedtakEndeligPlanDato", OFTDate);

      addSimpleType(poTypes, "KUNNGJØRINGSDATO", "kunngjøringsdato", OFTDate);

      addSimpleType(poTypes, "KPBESTEMMELSEHJEMMEL", "kpBestemmelseHjemmel", OFTInteger);

      addSimpleType(poTypes, "RPBESTEMMELSEHJEMMEL", "rpBestemmelseHjemmel", OFTInteger);

      addSimpleType(poTypes, "CCDBRIKKELENGDE", "ccdBrikkelengde", OFTInteger);

      addSimpleType(poTypes, "CCDBRIKKESIDE", "ccdBrikkeside", OFTInteger);

      addSimpleType(poTypes, "BILDEOPPLØSNING", "bildeoppløsning", OFTReal);

      addSimpleType(poTypes, "BILDEFILFORMAT", "bildefilformat", OFTInteger);

      addSimpleType(poTypes, "STATLIGNR", "statlignummer", OFTInteger);

      addSimpleType(poTypes, "AEROTRIANGULERING", "aerotriangulering", OFTInteger);

      addSimpleType(poTypes, "PROSJEKTRAPPORTLINK", "prosjektrapportlink", OFTString);

      addSimpleType(poTypes, "BILDEFILIR", "bildefilIr", OFTString);

      addSimpleType(poTypes, "BILDEFILPAN", "bildefilPan", OFTString);

      addSimpleType(poTypes, "BILDEFILRGB", "bildefilRGB", OFTString);

      addSimpleType(poTypes, "BILDEFILMULTI", "bildefilMulti", OFTString);

      addSimpleType(poTypes, "ORTOFOTOTYPE", "ortofototype", OFTInteger);

      addSimpleType(poTypes, "KAMERALØPENUMMER", "løpenummer", OFTInteger);

      addSimpleType(poTypes, "PRODUKSJONSRAPPORTLINK", "produksjonsrapportlink", OFTString);

      addSimpleType(poTypes, "PRODUKTSPESIFIKASJONSLINK", "produktspesifikasjonslink", OFTString);

      addSimpleType(poTypes, "SAKSÅR", "saksår", OFTInteger);

      addSimpleType(poTypes, "SEKVENSNUMMER", "sekvensnummer", OFTInteger);

      addSimpleType(poTypes, "UTNTALL_MIN", "utnyttingstall_minimum", OFTReal);

      addSimpleType(poTypes, "GYLDIGTILDATO", "gyldigTilDato", OFTDate);

      addSimpleType(poTypes, "PIXELSTØRRELSE", "pixelstørrelse", OFTReal);

      addSimpleType(poTypes, "HENDELSESDATO", "Hendelsesdato", OFTDate);

      addSimpleType(poTypes, "NPPLANBESTEMMELSETYPE", "planbestemmelsetype", OFTInteger);

      addSimpleType(poTypes, "NPPLANTEMA", "planTema", OFTInteger);

      addSimpleType(poTypes, "FAGOMRÅDE_LINK", "link til fagområde", OFTString);

      addSimpleType(poTypes, "PRODUKT_LINK", "produktLink", OFTString);

OGRSOSIDataType ADRESSEBRUKSENHETType = OGRSOSIDataType(3);

OGRSOSIDataType ADRESSEKOMMENTARType = OGRSOSIDataType(5);

OGRSOSIDataType ADRESSEREFERANSEType = OGRSOSIDataType(2);

OGRSOSIDataType ADRESSETILLEGGType = OGRSOSIDataType(3);

OGRSOSIDataType AIDType = OGRSOSIDataType(3);

OGRSOSIDataType AJOURFOeRINGType = OGRSOSIDataType(2);

OGRSOSIDataType AKVA_KONS_INFOType = OGRSOSIDataType(7);

OGRSOSIDataType AKVA_PROeVE_INFOType = OGRSOSIDataType(9);

OGRSOSIDataType ANDELType = OGRSOSIDataType(2);

OGRSOSIDataType AREALFORDELINGType = OGRSOSIDataType(5);

OGRSOSIDataType BELASTNINGBOF5Type = OGRSOSIDataType(4);

OGRSOSIDataType BELASTNINGFOSFORType = OGRSOSIDataType(4);

OGRSOSIDataType BEREGNETAREALType = OGRSOSIDataType(2);

OGRSOSIDataType BILDEINFORMASJONType = OGRSOSIDataType(3);

OGRSOSIDataType BMARTOBSType = OGRSOSIDataType(4);

OGRSOSIDataType BMARTREGType = OGRSOSIDataType(8);

OGRSOSIDataType BMKILDEType = OGRSOSIDataType(2);

OGRSOSIDataType BMNATYPTILLEGGType = OGRSOSIDataType(2);

OGRSOSIDataType BRUKSENHETType = OGRSOSIDataType(10);

OGRSOSIDataType BYDELIDType = OGRSOSIDataType(2);

OGRSOSIDataType BYGG_KOMMENTARERType = OGRSOSIDataType(5);

OGRSOSIDataType BYGN_STAT_HISTType = OGRSOSIDataType(3);

OGRSOSIDataType BYGNING_TILLEGGType = OGRSOSIDataType(15);

OGRSOSIDataType BYGNINGSREFType = OGRSOSIDataType(2);

OGRSOSIDataType DELOMRAaDEIDType = OGRSOSIDataType(2);

OGRSOSIDataType DPOT_GRASType = OGRSOSIDataType(4);

OGRSOSIDataType DPOT_KORNType = OGRSOSIDataType(4);

OGRSOSIDataType DPOT_POTETType = OGRSOSIDataType(4);

OGRSOSIDataType EKOORDType = OGRSOSIDataType(3);

OGRSOSIDataType ENDRINGSFLAGGType = OGRSOSIDataType(2);

OGRSOSIDataType ENDRINGSVURDERINGType = OGRSOSIDataType(2);

OGRSOSIDataType ETASJEType = OGRSOSIDataType(8);

OGRSOSIDataType ETASJEDATAType = OGRSOSIDataType(6);

OGRSOSIDataType FELTREGISTRERTType = OGRSOSIDataType(3);

OGRSOSIDataType FIRMA_EIERType = OGRSOSIDataType(7);

OGRSOSIDataType FISKE_BEDR_IDType = OGRSOSIDataType(6);

OGRSOSIDataType FISKE_BEDR_INFOType = OGRSOSIDataType(2);

OGRSOSIDataType FISKE_BEDR_MARKEDType = OGRSOSIDataType(2);

OGRSOSIDataType FISKE_BEDR_TJENESTEType = OGRSOSIDataType(3);

OGRSOSIDataType FISKERI_REDSKAPType = OGRSOSIDataType(4);

OGRSOSIDataType FISKERI_RESS_ARTType = OGRSOSIDataType(6);

OGRSOSIDataType FISKERI_RESSURSType = OGRSOSIDataType(2);

OGRSOSIDataType FMDATOType = OGRSOSIDataType(2);

OGRSOSIDataType FMIDNYType = OGRSOSIDataType(4);

OGRSOSIDataType FMSIGNType = OGRSOSIDataType(2);

OGRSOSIDataType FMSTATUSType = OGRSOSIDataType(2);

OGRSOSIDataType FMTYPEType = OGRSOSIDataType(5);

OGRSOSIDataType FORUR_GRUNN_EIENDOMType = OGRSOSIDataType(2);

OGRSOSIDataType GRENSE_MELLOMType = OGRSOSIDataType(2);

OGRSOSIDataType GRUNNKRETSIDType = OGRSOSIDataType(2);

OGRSOSIDataType HAVNE_D_INFOType = OGRSOSIDataType(2);

OGRSOSIDataType HOVEDMAaLRUBRIKKType = OGRSOSIDataType(2);

OGRSOSIDataType HOVEDNRType = OGRSOSIDataType(2); // Note: fixed manually by E.Rouault. Was 1 initially, but Valgrind complained

OGRSOSIDataType HYTTEINFORMASJONType = OGRSOSIDataType(3);

OGRSOSIDataType JORDTYPEType = OGRSOSIDataType(6);

OGRSOSIDataType JREGMARKType = OGRSOSIDataType(10);

OGRSOSIDataType JREGTEIGType = OGRSOSIDataType(4);

OGRSOSIDataType KAI_INFOType = OGRSOSIDataType(3);

OGRSOSIDataType KAMERAINFORMASJONType = OGRSOSIDataType(9);

OGRSOSIDataType KM_DAT_INFOType = OGRSOSIDataType(2);

OGRSOSIDataType KM_DATERINGType = OGRSOSIDataType(2);

OGRSOSIDataType KOMMUNALKRETSType = OGRSOSIDataType(4);

OGRSOSIDataType KOPIDATAType = OGRSOSIDataType(3);

OGRSOSIDataType KOPLINGType = OGRSOSIDataType(8);

OGRSOSIDataType KURSLINJE_INFOType = OGRSOSIDataType(4);

OGRSOSIDataType KVALITETType = OGRSOSIDataType(6);

OGRSOSIDataType LEDNINGType = OGRSOSIDataType(8);

OGRSOSIDataType LEGGEAaRType = OGRSOSIDataType(2);

OGRSOSIDataType LGIDType = OGRSOSIDataType(8);

OGRSOSIDataType MATRIKKELADRESSEIDType = OGRSOSIDataType(2);

OGRSOSIDataType MATRIKKELNUMMERType = OGRSOSIDataType(5);

OGRSOSIDataType OVERLAPPType = OGRSOSIDataType(2);

OGRSOSIDataType POSTType = OGRSOSIDataType(2);

OGRSOSIDataType REGISTRERINGSVERSJONType = OGRSOSIDataType(2);

OGRSOSIDataType RESIPIENTType = OGRSOSIDataType(5);

OGRSOSIDataType RETNINGType = OGRSOSIDataType(3);

OGRSOSIDataType ROeR_DIMENSJONType = OGRSOSIDataType(2);

OGRSOSIDataType SAKType = OGRSOSIDataType(4);

OGRSOSIDataType SEFRAK_IDType = OGRSOSIDataType(3);

OGRSOSIDataType SEFRAKFUNKSJONType = OGRSOSIDataType(2);

OGRSOSIDataType SENTRUMSSONEIDType = OGRSOSIDataType(2);

OGRSOSIDataType SERVType = OGRSOSIDataType(3);

OGRSOSIDataType SKRETSIDType = OGRSOSIDataType(2);

OGRSOSIDataType SP_ADMType = OGRSOSIDataType(2);

OGRSOSIDataType SP_AKLASSType = OGRSOSIDataType(6);

OGRSOSIDataType SP_BESTANDType = OGRSOSIDataType(2);

OGRSOSIDataType SP_BSKRIVType = OGRSOSIDataType(13);

OGRSOSIDataType SP_FLBRELEMType = OGRSOSIDataType(5);

OGRSOSIDataType SP_GRLVOLType = OGRSOSIDataType(8);

OGRSOSIDataType SP_TEIGType = OGRSOSIDataType(4);

OGRSOSIDataType SP_TERKLASSType = OGRSOSIDataType(5);

OGRSOSIDataType SP_TETTHOYDType = OGRSOSIDataType(2);

OGRSOSIDataType SP_TILTAKType = OGRSOSIDataType(5);

OGRSOSIDataType SP_TILVVOLType = OGRSOSIDataType(4);

OGRSOSIDataType SP_TRESLType = OGRSOSIDataType(8);

OGRSOSIDataType TETTSTEDIDType = OGRSOSIDataType(2);

OGRSOSIDataType UNIVERSELLUTFORMINGType = OGRSOSIDataType(3);

OGRSOSIDataType UTNYTTType = OGRSOSIDataType(2);

OGRSOSIDataType UTSLIPPType = OGRSOSIDataType(3);

OGRSOSIDataType UTV_TILL_PARTType = OGRSOSIDataType(2);

OGRSOSIDataType VERNType = OGRSOSIDataType(4);

OGRSOSIDataType VKRETSType = OGRSOSIDataType(2);

OGRSOSIDataType VNRType = OGRSOSIDataType(3);

OGRSOSIDataType VPAType = OGRSOSIDataType(3);
   ADRESSEBRUKSENHETType.setElement(1, "etasjenummer", OFTInteger);
   ADRESSEBRUKSENHETType.setElement(2, "etasjeplan", OFTString);
   ADRESSEBRUKSENHETType.setElement(0, "bruksenhetLøpenr", OFTInteger);
   ADRESSEKOMMENTARType.setElement(0, "etat", OFTString);
   ADRESSEKOMMENTARType.setElement(2, "kommentar", OFTString);
   ADRESSEKOMMENTARType.setElement(1, "kommentarType", OFTString);
   ADRESSEKOMMENTARType.setElement(4, "lagretDato", OFTDate);
   ADRESSEKOMMENTARType.setElement(3, "saksnummer", OFTInteger);
   ADRESSEREFERANSEType.setElement(1, "adresseReferansekode", OFTString);
   ADRESSEREFERANSEType.setElement(0, "referanse", OFTString);
   ADRESSETILLEGGType.setElement(1, "adresseKommentar", OFTString);
   ADRESSETILLEGGType.setElement(2, "adresseReferanse", OFTString);
   ADRESSETILLEGGType.setElement(0, "kartbladindeks", OFTString);
   AIDType.setElement(2, "bokstav", OFTString);
   AIDType.setElement(0, "gatenummer", OFTInteger);
   AIDType.setElement(1, "husnummer", OFTInteger);
   AJOURFOeRINGType.setElement(1, "ajourførtAv", OFTString);
   AJOURFOeRINGType.setElement(0, "ajourførtDato", OFTDate);
   AKVA_KONS_INFOType.setElement(1, "akvaKonsesjonsnummer", OFTInteger);
   AKVA_KONS_INFOType.setElement(4, "konsesjonsstatus", OFTString);
   AKVA_KONS_INFOType.setElement(6, "konsesjonstype", OFTString);
   AKVA_KONS_INFOType.setElement(5, "konsesjonsformål", OFTString);
   AKVA_KONS_INFOType.setElement(0, "fiskebruksnummerFylke", OFTString);
   AKVA_KONS_INFOType.setElement(2, "lokalitetsnavn", OFTString);
   AKVA_KONS_INFOType.setElement(3, "lokalitetsnummer", OFTInteger);
   AKVA_PROeVE_INFOType.setElement(7, "akvaTemperatur", OFTInteger);
   AKVA_PROeVE_INFOType.setElement(1, "algekonsentrasjon", OFTInteger);
   AKVA_PROeVE_INFOType.setElement(0, "algetype", OFTString);
   AKVA_PROeVE_INFOType.setElement(5, "klorofyllMaksimum", OFTInteger);
   AKVA_PROeVE_INFOType.setElement(8, "salinitet", OFTInteger);
   AKVA_PROeVE_INFOType.setElement(6, "sikteDyp", OFTInteger);
   AKVA_PROeVE_INFOType.setElement(2, "strømretning", OFTInteger);
   AKVA_PROeVE_INFOType.setElement(4, "vindretning", OFTInteger);
   ANDELType.setElement(1, "nevner", OFTReal);
   ANDELType.setElement(0, "teller", OFTReal);
   AREALFORDELINGType.setElement(4, "prosentElv", OFTReal);
   AREALFORDELINGType.setElement(2, "prosentHav", OFTReal);
   AREALFORDELINGType.setElement(3, "prosentInnsjø", OFTReal);
   AREALFORDELINGType.setElement(1, "prosentLand", OFTReal);
   AREALFORDELINGType.setElement(0, "totalarealKm2", OFTReal);
   BELASTNINGBOF5Type.setElement(2, "andrekilderBelastning", OFTInteger);
   BELASTNINGBOF5Type.setElement(0, "husholdBelastning", OFTInteger);
   BELASTNINGBOF5Type.setElement(1, "industriBelastning", OFTInteger);
   BELASTNINGBOF5Type.setElement(3, "totalbelastning", OFTInteger);
   BELASTNINGFOSFORType.setElement(2, "andrekilderBelastning", OFTInteger);
   BELASTNINGFOSFORType.setElement(0, "husholdBelastning", OFTInteger);
   BELASTNINGFOSFORType.setElement(1, "industriBelastning", OFTInteger);
   BELASTNINGFOSFORType.setElement(3, "totalbelastning", OFTInteger);
   BEREGNETAREALType.setElement(0, "areal", OFTReal);
   BEREGNETAREALType.setElement(1, "arealmerknad", OFTString);
   BILDEINFORMASJONType.setElement(1, "brennvidde", OFTReal);
   BILDEINFORMASJONType.setElement(2, "fotograf", OFTString);
   BILDEINFORMASJONType.setElement(0, "kameratype", OFTString);
   BMARTOBSType.setElement(1, "bmAntall", OFTInteger);
   BMARTOBSType.setElement(0, "bmArt", OFTString);
   BMARTOBSType.setElement(2, "bmEnhet", OFTInteger);
   BMARTOBSType.setElement(3, "bmRegistreringsdato", OFTDate);
   BMARTREGType.setElement(6, "bmÅrstid", OFTInteger);
   BMARTREGType.setElement(0, "bmArt", OFTString);
   BMARTREGType.setElement(2, "bmOmrådefunksjon", OFTInteger);
   BMARTREGType.setElement(5, "bmFunksjonskvalitet", OFTInteger);
   BMARTREGType.setElement(7, "bmKilde", OFTString);
   BMARTREGType.setElement(1, "bmRegistreringsdato", OFTDate);
   BMARTREGType.setElement(3, "bmTruethetskategori", OFTString);
   BMARTREGType.setElement(4, "bmViltvekt", OFTInteger);
   BMKILDEType.setElement(1, "bmKildetype", OFTInteger);
   BMKILDEType.setElement(0, "bmKildevurdering", OFTInteger);
   BMNATYPTILLEGGType.setElement(1, "bmAndel", OFTInteger);
   BMNATYPTILLEGGType.setElement(0, "bmNaturtype", OFTString);
   BRUKSENHETType.setElement(7, "antallBad", OFTInteger);
   BRUKSENHETType.setElement(6, "antallRom", OFTInteger);
   BRUKSENHETType.setElement(8, "antallWC", OFTInteger);
   BRUKSENHETType.setElement(5, "bruksareal", OFTReal);
   BRUKSENHETType.setElement(4, "bruksenhetstype", OFTString);
   BRUKSENHETType.setElement(2, "etasjenummer", OFTInteger);
   BRUKSENHETType.setElement(1, "etasjeplan", OFTString);
   BRUKSENHETType.setElement(9, "kjøkkenTilgang", OFTInteger);
   BRUKSENHETType.setElement(3, "bruksenhetLøpenr", OFTInteger);
   BRUKSENHETType.setElement(0, "matrikkelnummer", OFTString);
   BYDELIDType.setElement(0, "bydelsnavn", OFTString);
   BYDELIDType.setElement(1, "bydelsnummer", OFTInteger);
   BYGG_KOMMENTARERType.setElement(3, "bygnSaksnr", OFTString);
   BYGG_KOMMENTARERType.setElement(0, "etat", OFTString);
   BYGG_KOMMENTARERType.setElement(2, "kommentar", OFTString);
   BYGG_KOMMENTARERType.setElement(1, "kommentarType", OFTString);
   BYGG_KOMMENTARERType.setElement(4, "lagretDato", OFTDate);
   BYGN_STAT_HISTType.setElement(0, "bygningsstatus", OFTString);
   BYGN_STAT_HISTType.setElement(1, "bygningshistorikkDato", OFTDate);
   BYGN_STAT_HISTType.setElement(2, "registrertDato", OFTDate);
   BYGNING_TILLEGGType.setElement(0, "alternativtArealBygning", OFTReal);
   BYGNING_TILLEGGType.setElement(1, "antallEtasjer", OFTInteger);
   BYGNING_TILLEGGType.setElement(2, "antallRøkløp", OFTReal);
   BYGNING_TILLEGGType.setElement(3, "brenseltankNedgravd", OFTInteger);
   BYGNING_TILLEGGType.setElement(14, "bygningKommentar", OFTString);
   BYGNING_TILLEGGType.setElement(13, "bygningsreferanse", OFTString);
   BYGNING_TILLEGGType.setElement(9, "fundamentering", OFTInteger);
   BYGNING_TILLEGGType.setElement(12, "horisontalBærekonstr", OFTInteger);
   BYGNING_TILLEGGType.setElement(5, "kartbladindeks", OFTString);
   BYGNING_TILLEGGType.setElement(6, "kildePrivatVannforsyning", OFTInteger);
   BYGNING_TILLEGGType.setElement(10, "materialeIYttervegg", OFTInteger);
   BYGNING_TILLEGGType.setElement(7, "privatKloakkRensing", OFTInteger);
   BYGNING_TILLEGGType.setElement(8, "renovasjon", OFTInteger);
   BYGNING_TILLEGGType.setElement(4, "septiktank", OFTString);
   BYGNING_TILLEGGType.setElement(11, "vertikalBærekonstr", OFTInteger);
   BYGNINGSREFType.setElement(1, "bygningReferansetype", OFTString);
   BYGNINGSREFType.setElement(0, "referanse", OFTString);
   DELOMRAaDEIDType.setElement(0, "delområdenavn", OFTString);
   DELOMRAaDEIDType.setElement(1, "delområdenummer", OFTString);
   DPOT_GRASType.setElement(2, "nedbørsbasert", OFTInteger);
   DPOT_GRASType.setElement(3, "nedklassifiseringNedbør", OFTInteger);
   DPOT_GRASType.setElement(0, "vanningsbasert", OFTInteger);
   DPOT_GRASType.setElement(1, "nedklassifiseringVanning", OFTInteger);
   DPOT_KORNType.setElement(2, "nedbørsbasert", OFTInteger);
   DPOT_KORNType.setElement(3, "nedklassifiseringNedbør", OFTInteger);
   DPOT_KORNType.setElement(0, "vanningsbasert", OFTInteger);
   DPOT_KORNType.setElement(1, "nedklassifiseringVanning", OFTInteger);
   DPOT_POTETType.setElement(2, "nedbørsbasert", OFTInteger);
   DPOT_POTETType.setElement(3, "nedklassifiseringNedbør", OFTInteger);
   DPOT_POTETType.setElement(0, "vanningsbasert", OFTInteger);
   DPOT_POTETType.setElement(1, "nedklassifiseringVanning", OFTInteger);
   EKOORDType.setElement(2, "jordregisterKoordinatHøyde", OFTInteger);
   EKOORDType.setElement(0, "jordregisterKoordinatNord", OFTInteger);
   EKOORDType.setElement(1, "jordregisterKoordinatØst", OFTInteger);
   ENDRINGSFLAGGType.setElement(1, "tidspunktEndring", OFTDateTime);
   ENDRINGSFLAGGType.setElement(0, "typeEndring", OFTString);
   ENDRINGSVURDERINGType.setElement(0, "endringsgrad", OFTString);
   ENDRINGSVURDERINGType.setElement(1, "vurdertDato", OFTDate);
   ETASJEType.setElement(2, "antallBoenheter", OFTInteger);
   ETASJEType.setElement(4, "bruksarealTilAnnet", OFTReal);
   ETASJEType.setElement(3, "bruksarealTilBolig", OFTReal);
   ETASJEType.setElement(5, "bruksarealTotalt", OFTReal);
   ETASJEType.setElement(1, "etasjenummer", OFTInteger);
   ETASJEType.setElement(0, "etasjeplan", OFTString);
   ETASJEType.setElement(6, "kommAlternativtAreal", OFTReal);
   ETASJEType.setElement(7, "kommAlternativtAreal2", OFTReal);
   ETASJEDATAType.setElement(4, "sumAlternativtAreal", OFTReal);
   ETASJEDATAType.setElement(5, "sumAlternativtAreal2", OFTReal);
   ETASJEDATAType.setElement(0, "sumAntallBoenheter", OFTInteger);
   ETASJEDATAType.setElement(3, "sumBruksarealTotalt", OFTReal);
   ETASJEDATAType.setElement(2, "sumBruksarealTilAnnet", OFTReal);
   ETASJEDATAType.setElement(1, "sumBruksarealTilBolig", OFTReal);
   FELTREGISTRERTType.setElement(2, "ajourføring", OFTString);
   FELTREGISTRERTType.setElement(1, "datafangstdato", OFTDateTime);
   FELTREGISTRERTType.setElement(0, "feltregistrertAv", OFTString);
   FIRMA_EIERType.setElement(2, "adresse", OFTString);
   FIRMA_EIERType.setElement(0, "firmanavn", OFTString);
   FIRMA_EIERType.setElement(1, "bedriftseier", OFTString);
   FIRMA_EIERType.setElement(6, "kontaktperson", OFTString);
   FIRMA_EIERType.setElement(3, "postnummer", OFTInteger);
   FIRMA_EIERType.setElement(5, "telefaxnummer", OFTInteger);
   FIRMA_EIERType.setElement(4, "telefonnummer", OFTInteger);
   FISKE_BEDR_IDType.setElement(4, "antallAnsatte", OFTInteger);
   FISKE_BEDR_IDType.setElement(5, "antallÅrsverk", OFTInteger);
   FISKE_BEDR_IDType.setElement(0, "fiskebedriftsnavn", OFTString);
   FISKE_BEDR_IDType.setElement(2, "fiskebruksnummer", OFTInteger);
   FISKE_BEDR_IDType.setElement(1, "fiskebruksnummerFylke", OFTString);
   FISKE_BEDR_IDType.setElement(3, "firmaeier", OFTString);
   FISKE_BEDR_INFOType.setElement(1, "artskode", OFTInteger);
   FISKE_BEDR_INFOType.setElement(0, "fisketype", OFTInteger);
   FISKE_BEDR_MARKEDType.setElement(0, "fiskebedriftsandel", OFTInteger);
   FISKE_BEDR_MARKEDType.setElement(1, "fiskebedriftsområde", OFTInteger);
   FISKE_BEDR_TJENESTEType.setElement(2, "fiskebedriftservice", OFTInteger);
   FISKE_BEDR_TJENESTEType.setElement(1, "fiskekapasitetEnhet", OFTInteger);
   FISKE_BEDR_TJENESTEType.setElement(0, "fiskekapasitet", OFTInteger);
   FISKERI_REDSKAPType.setElement(0, "fiskeriredskapGenAktiv", OFTInteger);
   FISKERI_REDSKAPType.setElement(1, "fiskeriredskapGenPassiv", OFTInteger);
   FISKERI_REDSKAPType.setElement(2, "fiskeriredskapSpesAktiv", OFTInteger);
   FISKERI_REDSKAPType.setElement(3, "fiskeriredskapSpesPassiv", OFTInteger);
   FISKERI_RESS_ARTType.setElement(3, "engelskArtsnavn", OFTString);
   FISKERI_RESS_ARTType.setElement(2, "vitenskapeligArtsnavn", OFTString);
   FISKERI_RESS_ARTType.setElement(1, "norskArtsnavn", OFTString);
   FISKERI_RESS_ARTType.setElement(0, "taksonomiskKode", OFTInteger);
   FISKERI_RESS_ARTType.setElement(4, "faoKode", OFTString);
   FISKERI_RESS_ARTType.setElement(5, "artskode", OFTInteger);
   FISKERI_RESSURSType.setElement(0, "fiskeriressursområdeArt", OFTString);
   FISKERI_RESSURSType.setElement(1, "periode", OFTString);
   FMDATOType.setElement(1, "beregningsDato", OFTDate);
   FMDATOType.setElement(0, "fastmerkeEtableringsdato", OFTDate);
   FMIDNYType.setElement(1, "fastmerkeInstitusjon", OFTString);
   FMIDNYType.setElement(0, "fastmerkeKommune", OFTInteger);
   FMIDNYType.setElement(2, "fastmerkeNummer", OFTString);
   FMIDNYType.setElement(3, "indikatorFastmerkenummer", OFTString);
   FMSIGNType.setElement(1, "signalHøyde", OFTReal);
   FMSIGNType.setElement(0, "signalType", OFTString);
   FMSTATUSType.setElement(1, "typeStatus", OFTInteger);
   FMSTATUSType.setElement(0, "verifiseringsdato", OFTDateTime);
   FMTYPEType.setElement(0, "boltType", OFTInteger);
   FMTYPEType.setElement(3, "fastmerkeDiameter", OFTInteger);
   FMTYPEType.setElement(4, "gravertTekst", OFTString);
   FMTYPEType.setElement(1, "materialeBolt", OFTInteger);
   FMTYPEType.setElement(2, "fastmerkeUnderlag", OFTInteger);
   FORUR_GRUNN_EIENDOMType.setElement(1, "arealbrukRestriksjon", OFTInteger);
   FORUR_GRUNN_EIENDOMType.setElement(0, "matrikkelnummer", OFTString);
   GRENSE_MELLOMType.setElement(0, "førsteLand", OFTString);
   GRENSE_MELLOMType.setElement(1, "annetLand", OFTString);
   GRUNNKRETSIDType.setElement(1, "grunnkretsnavn", OFTString);
   GRUNNKRETSIDType.setElement(0, "grunnkretsnummer", OFTInteger);
   HAVNE_D_INFOType.setElement(1, "havnedistriktAdministrasjon", OFTInteger);
   HAVNE_D_INFOType.setElement(0, "kommune", OFTInteger);
   HOVEDMAaLRUBRIKKType.setElement(1, "bredde", OFTInteger);
   HOVEDMAaLRUBRIKKType.setElement(0, "lengde", OFTInteger);
   HOVEDNRType.setElement(1, " kommunenummer", OFTInteger);
   HOVEDNRType.setElement(0, "matrikkelnummer", OFTString);
   HYTTEINFORMASJONType.setElement(1, "betjeningsgrad", OFTString);
   HYTTEINFORMASJONType.setElement(0, "hytteId", OFTInteger);
   HYTTEINFORMASJONType.setElement(2, "hytteeier", OFTInteger);
   JORDTYPEType.setElement(0, "serie1", OFTString);
   JORDTYPEType.setElement(2, "serie2", OFTString);
   JORDTYPEType.setElement(4, "serie3", OFTString);
   JORDTYPEType.setElement(1, "tekstur1", OFTString);
   JORDTYPEType.setElement(3, "tekstur2", OFTString);
   JORDTYPEType.setElement(5, "tekstur3", OFTString);
   JREGMARKType.setElement(1, "potensiellSkogbonitetOmkodet", OFTInteger);
   JREGMARKType.setElement(0, "arealtilstand", OFTInteger);
   JREGMARKType.setElement(7, "jordregisterDyrkingsjord", OFTString);
   JREGMARKType.setElement(6, "jordregisterFreg", OFTInteger);
   JREGMARKType.setElement(5, "jordregisterLreg", OFTString);
   JREGMARKType.setElement(3, "jordklassifikasjon", OFTInteger);
   JREGMARKType.setElement(4, "myrklassifikasjon", OFTInteger);
   JREGMARKType.setElement(8, "jordregisterSkogtype", OFTInteger);
   JREGMARKType.setElement(9, "jordregisterSkogreisningsmark", OFTInteger);
   JREGMARKType.setElement(2, "tilleggsopplysningerSkog", OFTInteger);
   JREGTEIGType.setElement(2, "jordregisterDriftssenter", OFTInteger);
   JREGTEIGType.setElement(3, "jordregisterStatusEiendom", OFTInteger);
   JREGTEIGType.setElement(0, "matrikkelnummer", OFTString);
   JREGTEIGType.setElement(1, "jordregisterEiendomTeigNummer", OFTInteger);
   KAI_INFOType.setElement(1, "kaiDybde", OFTReal);
   KAI_INFOType.setElement(0, "kaiType", OFTInteger);
   KAI_INFOType.setElement(2, "kommunenummer", OFTInteger);
   KAMERAINFORMASJONType.setElement(4, "bildekategori", OFTInteger);
   KAMERAINFORMASJONType.setElement(3, "brennvidde", OFTReal);
   KAMERAINFORMASJONType.setElement(7, "film", OFTString);
   KAMERAINFORMASJONType.setElement(8, "kalibreringsrapport", OFTString);
   KAMERAINFORMASJONType.setElement(1, "kameratype", OFTString);
   KAMERAINFORMASJONType.setElement(0, "opptaksmetode", OFTInteger);
   KM_DAT_INFOType.setElement(0, "sefrakTiltak", OFTInteger);
   KM_DAT_INFOType.setElement(1, "tidsangivelse", OFTInteger);
   KM_DATERINGType.setElement(0, "kulturminneDatering", OFTString);
   KM_DATERINGType.setElement(1, "kulturminneDateringKvalitet", OFTString);
   KOMMUNALKRETSType.setElement(3, "kretsnavn", OFTString);
   KOMMUNALKRETSType.setElement(2, "kretsnummer", OFTString);
   KOMMUNALKRETSType.setElement(0, "kretstypekode", OFTString);
   KOMMUNALKRETSType.setElement(1, "kretstypenavn", OFTString);
   KOPIDATAType.setElement(2, "kopidato", OFTDateTime);
   KOPIDATAType.setElement(0, "områdeId", OFTInteger);
   KOPIDATAType.setElement(1, "originalDatavert", OFTString);
   KOPLINGType.setElement(1, "fagområde", OFTInteger);
   KOPLINGType.setElement(4, "bruksområde", OFTString);
   KOPLINGType.setElement(2, "koplingskategori", OFTInteger);
   KOPLINGType.setElement(0, "koplingsnavn", OFTString);
   KOPLINGType.setElement(3, "koplingstype", OFTString);
   KOPLINGType.setElement(7, "bildelink", OFTString);
   KOPLINGType.setElement(5, "materiellkode", OFTString);
   KOPLINGType.setElement(6, "verdi", OFTInteger);
   KURSLINJE_INFOType.setElement(0, "fartøyIdentifikasjon", OFTString);
   KURSLINJE_INFOType.setElement(1, "satellittkommunikasjonsId", OFTString);
   KURSLINJE_INFOType.setElement(3, "sporhastighet", OFTInteger);
   KURSLINJE_INFOType.setElement(2, "tidspunkt", OFTDateTime);
   KVALITETType.setElement(3, "målemetodeHøyde", OFTInteger);
   KVALITETType.setElement(4, "nøyaktighetHøyde", OFTInteger);
   KVALITETType.setElement(5, "maksimaltAvvik", OFTInteger);
   KVALITETType.setElement(0, "målemetode", OFTInteger);
   KVALITETType.setElement(1, "nøyaktighet", OFTInteger);
   KVALITETType.setElement(2, "synbarhet", OFTInteger);
   LEDNINGType.setElement(1, "fagområde", OFTInteger);
   LEDNINGType.setElement(3, "bruksområde", OFTString);
   LEDNINGType.setElement(0, "ledningsnavn", OFTString);
   LEDNINGType.setElement(2, "ledningstype", OFTInteger);
   LEDNINGType.setElement(7, "leggeår", OFTString);
   LEDNINGType.setElement(6, "lengde", OFTReal);
   LEDNINGType.setElement(5, "materiellkode", OFTString);
   LEDNINGType.setElement(4, "nettnivå", OFTString);
   LEGGEAaRType.setElement(0, "alderReferanse", OFTInteger);
   LEGGEAaRType.setElement(1, "årstall", OFTInteger);
   LGIDType.setElement(7, "landbruksregAktiv", OFTInteger);
   LGIDType.setElement(6, "landbruksregType", OFTInteger);
   LGIDType.setElement(0, "matrikkelnummer", OFTString);
   MATRIKKELADRESSEIDType.setElement(0, "matrikkelnummer", OFTString);
   MATRIKKELADRESSEIDType.setElement(1, "undernr", OFTInteger);
   MATRIKKELNUMMERType.setElement(2, "bruksnummer", OFTInteger);
   MATRIKKELNUMMERType.setElement(3, "festenummer", OFTInteger);
   MATRIKKELNUMMERType.setElement(1, "gårdsnummer", OFTInteger);
   MATRIKKELNUMMERType.setElement(0, "matrikkelkommune", OFTInteger);
   MATRIKKELNUMMERType.setElement(4, "seksjonsnummer", OFTInteger);
   OVERLAPPType.setElement(0, "lengdeoverlapp", OFTInteger);
   OVERLAPPType.setElement(1, "sideoverlapp", OFTInteger);
   POSTType.setElement(1, "poststedsnavn", OFTString);
   POSTType.setElement(0, "postnummer", OFTInteger);
   REGISTRERINGSVERSJONType.setElement(0, "produkt", OFTString);
   REGISTRERINGSVERSJONType.setElement(1, "versjon", OFTString);
   RESIPIENTType.setElement(2, "fjordId", OFTString);
   RESIPIENTType.setElement(0, "resipientnavn", OFTString);
   RESIPIENTType.setElement(4, "resipienttype", OFTString);
   RESIPIENTType.setElement(1, "vassdragsnummer", OFTString);
   RESIPIENTType.setElement(3, "vatnLøpenummer", OFTInteger);
   RETNINGType.setElement(1, "retningsenhet", OFTInteger);
   RETNINGType.setElement(2, "retningsreferanse", OFTInteger);
   RETNINGType.setElement(0, "retningsverdi", OFTReal);
   ROeR_DIMENSJONType.setElement(1, "lengdeenhet", OFTString);
   ROeR_DIMENSJONType.setElement(0, "måltall", OFTReal);
   SAKType.setElement(3, "vedtaksmyndighet", OFTString);
   SAKType.setElement(0, "saksnummer", OFTInteger);
   SAKType.setElement(2, "utvalgssaksnummer", OFTInteger);
   SAKType.setElement(1, "vedtaksdato", OFTDate);
   SEFRAK_IDType.setElement(2, "husLøpenr", OFTInteger);
   SEFRAK_IDType.setElement(1, "registreringKretsnr", OFTInteger);
   SEFRAK_IDType.setElement(0, "SEFRAKkommune", OFTInteger);
   SEFRAKFUNKSJONType.setElement(0, "sefrakFunksjonskode", OFTInteger);
   SEFRAKFUNKSJONType.setElement(1, "sefrakFunksjonsstatus", OFTString);
   SENTRUMSSONEIDType.setElement(1, "sentrumssonenavn", OFTString);
   SENTRUMSSONEIDType.setElement(0, "sentrumssonenummer", OFTInteger);
   SERVType.setElement(2, "informasjon", OFTString);
   SERVType.setElement(0, "matrikkelnummer", OFTString);
   SERVType.setElement(1, "servituttType", OFTString);
   SKRETSIDType.setElement(1, "skolekretsnavn", OFTString);
   SKRETSIDType.setElement(0, "skolekretsnummer", OFTInteger);
   SP_ADMType.setElement(0, "skogbrplanAdmDatoEndring", OFTDate);
   SP_ADMType.setElement(1, "skogbrplanAdmDatoEtablering", OFTDate);
   SP_AKLASSType.setElement(0, "skogbrplanKlassAktueltTreslag", OFTInteger);
   SP_AKLASSType.setElement(1, "skogbrplanKlassAktSnittBon", OFTInteger);
   SP_AKLASSType.setElement(3, "skogbrplanKlassImpProsent", OFTInteger);
   SP_AKLASSType.setElement(2, "skogbrplanKlassImpType", OFTInteger);
   SP_AKLASSType.setElement(4, "skogbrplanKlassPotTreslag", OFTInteger);
   SP_AKLASSType.setElement(5, "skogbrplanKlassPotSnittBon", OFTInteger);
   SP_BESTANDType.setElement(1, "skogbrplanBestandDelNr", OFTInteger);
   SP_BESTANDType.setElement(0, "skogbrplanBestandNr", OFTInteger);
   SP_BSKRIVType.setElement(2, "skogbrplanBeskrivBestandAlder", OFTInteger);
   SP_BSKRIVType.setElement(3, "skogbrplanBeskrivBestandDaa", OFTReal);
   SP_BSKRIVType.setElement(6, "skogbrplanBeskrivBestSnittDiam", OFTInteger);
   SP_BSKRIVType.setElement(4, "skogbrplanBeskrivBestandSnittM2", OFTInteger);
   SP_BSKRIVType.setElement(5, "skogbrplanBeskrivBestandSnittH", OFTReal);
   SP_BSKRIVType.setElement(7, "skogbrplanBeskrivBarHøydehkl2", OFTInteger);
   SP_BSKRIVType.setElement(0, "skogbrplanBeskrivHogstklasse", OFTInteger);
   SP_BSKRIVType.setElement(8, "skogbrplanBeskrivLauvHøydehkl2", OFTInteger);
   SP_BSKRIVType.setElement(9, "skogbrplanBeskrivSjiktning", OFTInteger);
   SP_BSKRIVType.setElement(1, "skogbrplanBeskrivSkogtype", OFTInteger);
   SP_BSKRIVType.setElement(10, "skogbrplanBeskrivSunnhet", OFTInteger);
   SP_BSKRIVType.setElement(11, "skogbrplanBeskrivTreERegulering", OFTInteger);
   SP_BSKRIVType.setElement(12, "skogbrplanBeskrivTreFRegulering", OFTInteger);
   SP_FLBRELEMType.setElement(0, "skogbrplanFlerKoderElementtype", OFTInteger);
   SP_FLBRELEMType.setElement(1, "skogbrplanFlerKoderArealProsent", OFTInteger);
   SP_FLBRELEMType.setElement(2, "skogbrplanFlerKoderArealDaa", OFTInteger);
   SP_FLBRELEMType.setElement(3, "skogbrplanFlerKoderSpesBehPros", OFTInteger);
   SP_FLBRELEMType.setElement(4, "skogbrplanFlerKoderSpesBehDaa", OFTInteger);
   SP_GRLVOLType.setElement(3, "skogbrplanGrunnlagVolumDaaFelt", OFTReal);
   SP_GRLVOLType.setElement(4, "skogbrplanGrunnlagVolumBestFelt", OFTInteger);
   SP_GRLVOLType.setElement(0, "skogbrplanGrunnlagBerType", OFTInteger);
   SP_GRLVOLType.setElement(2, "skogbrplanGrunnlagHovedgruppe", OFTInteger);
   SP_GRLVOLType.setElement(6, "skogbrplanGrunnlagRegion", OFTInteger);
   SP_GRLVOLType.setElement(5, "skogbrplanGrunnlagSvinnProsent", OFTInteger);
   SP_GRLVOLType.setElement(1, "skogbrplanGrunnlagTaksttype", OFTInteger);
   SP_GRLVOLType.setElement(7, "skogbrplanGrunnlagTilvekstkorr", OFTInteger);
   SP_TEIGType.setElement(3, "matrikkelnummer", OFTString);
   SP_TEIGType.setElement(2, "skogbrplanTeigGrend", OFTInteger);
   SP_TEIGType.setElement(0, "skogbrplanTeigNr", OFTInteger);
   SP_TEIGType.setElement(1, "skogbrplanTeigNavn", OFTString);
   SP_TERKLASSType.setElement(0, "skogbrplanTerrengBæreevneBestand", OFTInteger);
   SP_TERKLASSType.setElement(1, "skogbrplanTerrengBestandBratthet", OFTInteger);
   SP_TERKLASSType.setElement(2, "skogbrplanTerrengLiLengde", OFTInteger);
   SP_TERKLASSType.setElement(3, "skogbrplanTerrengMinTranspUtst", OFTInteger);
   SP_TERKLASSType.setElement(4, "skogbrplanTerrengJevnhet", OFTInteger);
   SP_TETTHOYDType.setElement(0, "skogbrplanTetthetGrunnflatesum", OFTInteger);
   SP_TETTHOYDType.setElement(1, "skogbrplanTetthetMHøyde", OFTInteger);
   SP_TILTAKType.setElement(3, "skogbrplanTiltakProritet", OFTInteger);
   SP_TILTAKType.setElement(1, "skogbrplanTiltakProsent", OFTInteger);
   SP_TILTAKType.setElement(4, "skogbrplanTiltakAreal", OFTReal);
   SP_TILTAKType.setElement(0, "skogbrplanTiltakBestand", OFTInteger);
   SP_TILTAKType.setElement(2, "skogbrplanTiltakÅr", OFTInteger);
   SP_TILVVOLType.setElement(0, "skogbrplanTilvekstBeregnDaa", OFTReal);
   SP_TILVVOLType.setElement(1, "skogbrplanTilvekstBeregnProsent", OFTReal);
   SP_TILVVOLType.setElement(2, "skogbrplanTilvekstBeregnM3", OFTReal);
   SP_TILVVOLType.setElement(3, "skogbrplanTilvekstVolumBestand", OFTInteger);
   SP_TRESLType.setElement(4, "skogbrplanTreslagAntTreDaaEReg", OFTInteger);
   SP_TRESLType.setElement(3, "skogbrplanTreslagAntTreDaaFReg", OFTInteger);
   SP_TRESLType.setElement(0, "skogbrplanTreslag", OFTInteger);
   SP_TRESLType.setElement(1, "skogbrplanTreslagHøyde", OFTInteger);
   SP_TRESLType.setElement(2, "skogbrplanTreslagProsent", OFTInteger);
   SP_TRESLType.setElement(5, "skogbrplanTreslagKorrVolumUBark", OFTInteger);
   SP_TRESLType.setElement(7, "skogbrplanTreslagSalgsvolumUBark", OFTInteger);
   SP_TRESLType.setElement(6, "skogbrplanTreslagUkorrVolumUBark", OFTInteger);
   TETTSTEDIDType.setElement(1, "tettstednavn", OFTString);
   TETTSTEDIDType.setElement(0, "tettstednummer", OFTInteger);
   UNIVERSELLUTFORMINGType.setElement(2, "informasjon", OFTString);
   UNIVERSELLUTFORMINGType.setElement(0, "tilgjengelighetsvurdering", OFTString);
   UNIVERSELLUTFORMINGType.setElement(1, "universellutformingFasilitet", OFTString);
   UTNYTTType.setElement(1, "utnyttingstall", OFTReal);
   UTNYTTType.setElement(0, "utnyttingstype", OFTInteger);
   UTSLIPPType.setElement(0, "komponent", OFTString);
   UTSLIPPType.setElement(1, "massestørrelse", OFTString);
   UTSLIPPType.setElement(2, "utslippType", OFTString);
   UTV_TILL_PARTType.setElement(1, "petroleumsandel", OFTReal);
   UTV_TILL_PARTType.setElement(0, "petroleumspartnere", OFTString);
   VERNType.setElement(0, "vernelov", OFTString);
   VERNType.setElement(1, "verneparagraf", OFTString);
   VERNType.setElement(3, "vernedato", OFTDate);
   VERNType.setElement(2, "vernetype", OFTString);
   VKRETSType.setElement(1, "valgkretsnavn", OFTString);
   VKRETSType.setElement(0, "valgkretsnummer", OFTInteger);
   VNRType.setElement(0, "vegkategori", OFTString);
   VNRType.setElement(2, "vegnummer", OFTInteger);
   VNRType.setElement(1, "vegstatus", OFTString);
   VPAType.setElement(0, "hovedParsell", OFTInteger);
   VPAType.setElement(1, "veglenkeMeterFra", OFTInteger);
   VPAType.setElement(2, "veglenkeMeterTil", OFTInteger);

addType(poTypes, "ADRESSEBRUKSENHET", &ADRESSEBRUKSENHETType);

addType(poTypes, "ADRESSEKOMMENTAR", &ADRESSEKOMMENTARType);

addType(poTypes, "ADRESSEREFERANSE", &ADRESSEREFERANSEType);

addType(poTypes, "ADRESSETILLEGG", &ADRESSETILLEGGType);

addType(poTypes, "AID", &AIDType);

addType(poTypes, "AJOURFØRING", &AJOURFOeRINGType);

addType(poTypes, "AKVA_KONS_INFO", &AKVA_KONS_INFOType);

addType(poTypes, "AKVA_PRØVE_INFO", &AKVA_PROeVE_INFOType);

addType(poTypes, "ANDEL", &ANDELType);

addType(poTypes, "AREALFORDELING", &AREALFORDELINGType);

addType(poTypes, "BELASTNINGBOF5", &BELASTNINGBOF5Type);

addType(poTypes, "BELASTNINGFOSFOR", &BELASTNINGFOSFORType);

addType(poTypes, "BEREGNETAREAL", &BEREGNETAREALType);

addType(poTypes, "BILDEINFORMASJON", &BILDEINFORMASJONType);

addType(poTypes, "BMARTOBS", &BMARTOBSType);

addType(poTypes, "BMARTREG", &BMARTREGType);

addType(poTypes, "BMKILDE", &BMKILDEType);

addType(poTypes, "BMNATYPTILLEGG", &BMNATYPTILLEGGType);

addType(poTypes, "BRUKSENHET", &BRUKSENHETType);

addType(poTypes, "BYDELID", &BYDELIDType);

addType(poTypes, "BYGG_KOMMENTARER", &BYGG_KOMMENTARERType);

addType(poTypes, "BYGN_STAT_HIST", &BYGN_STAT_HISTType);

addType(poTypes, "BYGNING_TILLEGG", &BYGNING_TILLEGGType);

addType(poTypes, "BYGNINGSREF", &BYGNINGSREFType);

addType(poTypes, "DELOMRÅDEID", &DELOMRAaDEIDType);

addType(poTypes, "DPOT_GRAS", &DPOT_GRASType);

addType(poTypes, "DPOT_KORN", &DPOT_KORNType);

addType(poTypes, "DPOT_POTET", &DPOT_POTETType);

addType(poTypes, "EKOORD", &EKOORDType);

addType(poTypes, "ENDRINGSFLAGG", &ENDRINGSFLAGGType);

addType(poTypes, "ENDRINGSVURDERING", &ENDRINGSVURDERINGType);

addType(poTypes, "ETASJE", &ETASJEType);

addType(poTypes, "ETASJEDATA", &ETASJEDATAType);

addType(poTypes, "FELTREGISTRERT", &FELTREGISTRERTType);

addType(poTypes, "FIRMA_EIER", &FIRMA_EIERType);

addType(poTypes, "FISKE_BEDR_ID", &FISKE_BEDR_IDType);

addType(poTypes, "FISKE_BEDR_INFO", &FISKE_BEDR_INFOType);

addType(poTypes, "FISKE_BEDR_MARKED", &FISKE_BEDR_MARKEDType);

addType(poTypes, "FISKE_BEDR_TJENESTE", &FISKE_BEDR_TJENESTEType);

addType(poTypes, "FISKERI_REDSKAP", &FISKERI_REDSKAPType);

addType(poTypes, "FISKERI_RESS_ART", &FISKERI_RESS_ARTType);

addType(poTypes, "FISKERI_RESSURS", &FISKERI_RESSURSType);

addType(poTypes, "FMDATO", &FMDATOType);

addType(poTypes, "FMIDNY", &FMIDNYType);

addType(poTypes, "FMSIGN", &FMSIGNType);

addType(poTypes, "FMSTATUS", &FMSTATUSType);

addType(poTypes, "FMTYPE", &FMTYPEType);

addType(poTypes, "FORUR_GRUNN_EIENDOM", &FORUR_GRUNN_EIENDOMType);

addType(poTypes, "GRENSE_MELLOM", &GRENSE_MELLOMType);

addType(poTypes, "GRUNNKRETSID", &GRUNNKRETSIDType);

addType(poTypes, "HAVNE_D_INFO", &HAVNE_D_INFOType);

addType(poTypes, "HOVEDMÅLRUBRIKK", &HOVEDMAaLRUBRIKKType);

addType(poTypes, "HOVEDNR", &HOVEDNRType);

addType(poTypes, "HYTTEINFORMASJON", &HYTTEINFORMASJONType);

addType(poTypes, "JORDTYPE", &JORDTYPEType);

addType(poTypes, "JREGMARK", &JREGMARKType);

addType(poTypes, "JREGTEIG", &JREGTEIGType);

addType(poTypes, "KAI_INFO", &KAI_INFOType);

addType(poTypes, "KAMERAINFORMASJON", &KAMERAINFORMASJONType);

addType(poTypes, "KM_DAT_INFO", &KM_DAT_INFOType);

addType(poTypes, "KM_DATERING", &KM_DATERINGType);

addType(poTypes, "KOMMUNALKRETS", &KOMMUNALKRETSType);

addType(poTypes, "KOPIDATA", &KOPIDATAType);

addType(poTypes, "KOPLING", &KOPLINGType);

addType(poTypes, "KURSLINJE_INFO", &KURSLINJE_INFOType);

addType(poTypes, "KVALITET", &KVALITETType);

addType(poTypes, "LEDNING", &LEDNINGType);

addType(poTypes, "LEGGEÅR", &LEGGEAaRType);

addType(poTypes, "LGID", &LGIDType);

addType(poTypes, "MATRIKKELADRESSEID", &MATRIKKELADRESSEIDType);

addType(poTypes, "MATRIKKELNUMMER", &MATRIKKELNUMMERType);

addType(poTypes, "OVERLAPP", &OVERLAPPType);

addType(poTypes, "POST", &POSTType);

addType(poTypes, "REGISTRERINGSVERSJON", &REGISTRERINGSVERSJONType);

addType(poTypes, "RESIPIENT", &RESIPIENTType);

addType(poTypes, "RETNING", &RETNINGType);

addType(poTypes, "RØR_DIMENSJON", &ROeR_DIMENSJONType);

addType(poTypes, "SAK", &SAKType);

addType(poTypes, "SEFRAK_ID", &SEFRAK_IDType);

addType(poTypes, "SEFRAKFUNKSJON", &SEFRAKFUNKSJONType);

addType(poTypes, "SENTRUMSSONEID", &SENTRUMSSONEIDType);

addType(poTypes, "SERV", &SERVType);

addType(poTypes, "SKRETSID", &SKRETSIDType);

addType(poTypes, "SP_ADM", &SP_ADMType);

addType(poTypes, "SP_AKLASS", &SP_AKLASSType);

addType(poTypes, "SP_BESTAND", &SP_BESTANDType);

addType(poTypes, "SP_BSKRIV", &SP_BSKRIVType);

addType(poTypes, "SP_FLBRELEM", &SP_FLBRELEMType);

addType(poTypes, "SP_GRLVOL", &SP_GRLVOLType);

addType(poTypes, "SP_TEIG", &SP_TEIGType);

addType(poTypes, "SP_TERKLASS", &SP_TERKLASSType);

addType(poTypes, "SP_TETTHOYD", &SP_TETTHOYDType);

addType(poTypes, "SP_TILTAK", &SP_TILTAKType);

addType(poTypes, "SP_TILVVOL", &SP_TILVVOLType);

addType(poTypes, "SP_TRESL", &SP_TRESLType);

addType(poTypes, "TETTSTEDID", &TETTSTEDIDType);

addType(poTypes, "UNIVERSELLUTFORMING", &UNIVERSELLUTFORMINGType);

addType(poTypes, "UTNYTT", &UTNYTTType);

addType(poTypes, "UTSLIPP", &UTSLIPPType);

addType(poTypes, "UTV_TILL_PART", &UTV_TILL_PARTType);

addType(poTypes, "VERN", &VERNType);

addType(poTypes, "VKRETS", &VKRETSType);

addType(poTypes, "VNR", &VNRType);

addType(poTypes, "VPA", &VPAType);
